@@ -407,8 +407,9 @@ run_at (struct GNUNET_TIME_Absolute deadline)
  * @param dr HTTP response data
  */
 static void
-deposit_get_cb (void *cls,
-                const struct TALER_EXCHANGE_GetDepositResponse *dr)
+deposit_get_cb (
+  void *cls,
+  const struct TALER_EXCHANGE_GetDepositResponse *dr)
 {
   struct ExchangeInteraction *w = cls;
   struct GNUNET_TIME_Absolute future_retry;
@@ -425,9 +426,10 @@ deposit_get_cb (void *cls,
                   "Exchange returned wire transfer over %s for deposited coin %s\n",
                   TALER_amount2s (&dr->details.ok.coin_contribution),
                   TALER_B2S (&w->coin_pub));
-      qs = db_plugin->insert_deposit_to_transfer (db_plugin->cls,
-                                                  w->deposit_serial,
-                                                  &dr->details.ok);
+      qs = db_plugin->insert_deposit_to_transfer (
+        db_plugin->cls,
+        w->deposit_serial,
+        &dr->details.ok);
       if (qs < 0)
       {
         GNUNET_break (0);
@@ -457,9 +459,8 @@ deposit_get_cb (void *cls,
       struct GNUNET_TIME_Timestamp now;
 
       GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                  "Exchange returned KYC requirement (%d/%d) for deposited coin %s\n",
+                  "Exchange returned KYC requirement (%d) for deposited coin %s\n",
                   dr->details.accepted.kyc_ok,
-                  dr->details.accepted.aml_decision,
                   TALER_B2S (&w->coin_pub));
       now = GNUNET_TIME_timestamp_get ();
       qs = db_plugin->account_kyc_set_status (
@@ -468,20 +469,21 @@ deposit_get_cb (void *cls,
         &w->h_wire,
         exchange_url,
         dr->details.accepted.requirement_row,
-        NULL,
-        NULL,
         now,
-        dr->details.accepted.kyc_ok,
-        dr->details.accepted.aml_decision);
+        MHD_HTTP_ACCEPTED,
+        TALER_EC_NONE,
+        NULL,
+        0,
+        NULL,
+        false,
+        dr->details.accepted.kyc_ok);
       if (qs < 0)
       {
         GNUNET_break (0);
         GNUNET_SCHEDULER_shutdown ();
         return;
       }
-      if (dr->details.accepted.kyc_ok &&
-          (TALER_AML_NORMAL ==
-           dr->details.accepted.aml_decision))
+      if (dr->details.accepted.kyc_ok)
       {
         GNUNET_log (GNUNET_ERROR_TYPE_INFO,
                     "Bumping wire transfer deadline in DB to %s as that is when we will retry\n",
@@ -604,7 +606,8 @@ pending_deposits_cb (
   const struct TALER_Amount *deposit_fee,
   const struct TALER_CoinSpendPublicKeyP *coin_pub)
 {
-  struct ExchangeInteraction *w = GNUNET_new (struct ExchangeInteraction);
+  struct ExchangeInteraction *w
+    = GNUNET_new (struct ExchangeInteraction);
 
   (void) cls;
   if (GNUNET_TIME_absolute_is_future (wire_deadline))
@@ -630,7 +633,8 @@ pending_deposits_cb (
                                w);
   w_count++;
   GNUNET_assert (NULL != keys);
-  if (GNUNET_TIME_absolute_is_past (keys->key_data_expiration.abs_time))
+  if (GNUNET_TIME_absolute_is_past (
+        keys->key_data_expiration.abs_time))
   {
     /* Parent should re-start us, then we will re-fetch /keys */
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
@@ -699,7 +703,8 @@ select_work (void *cls)
     GNUNET_break (0);
     return;
   }
-  if (GNUNET_TIME_absolute_is_past (keys->key_data_expiration.abs_time))
+  if (GNUNET_TIME_absolute_is_past (
+        keys->key_data_expiration.abs_time))
   {
     /* Parent should re-start us, then we will re-fetch /keys */
     GNUNET_SCHEDULER_shutdown ();
@@ -712,12 +717,13 @@ select_work (void *cls)
     db_plugin->preflight (db_plugin->cls);
     if (retry)
       limit = 1;
-    qs = db_plugin->lookup_pending_deposits (db_plugin->cls,
-                                             exchange_url,
-                                             limit,
-                                             retry,
-                                             &pending_deposits_cb,
-                                             NULL);
+    qs = db_plugin->lookup_pending_deposits (
+      db_plugin->cls,
+      exchange_url,
+      limit,
+      retry,
+      &pending_deposits_cb,
+      NULL);
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
                 "Looking up pending deposits query status was %d\n",
                 (int) qs);
@@ -798,17 +804,18 @@ start_worker (const char *base_url)
               "Launching worker for exchange `%s' using `%s`\n",
               base_url,
               cfg_filename);
-  return GNUNET_OS_start_process (GNUNET_OS_INHERIT_STD_ALL,
-                                  NULL,
-                                  NULL,
-                                  NULL,
-                                  "taler-merchant-depositcheck",
-                                  "taler-merchant-depositcheck",
-                                  "-c", cfg_filename,
-                                  "-e", base_url,
-                                  "-L", "INFO",
-                                  test_mode ? "-t" : NULL,
-                                  NULL);
+  return GNUNET_OS_start_process (
+    GNUNET_OS_INHERIT_STD_ALL,
+    NULL,
+    NULL,
+    NULL,
+    "taler-merchant-depositcheck",
+    "taler-merchant-depositcheck",
+    "-c", cfg_filename,
+    "-e", base_url,
+    "-L", "INFO",
+    test_mode ? "-t" : NULL,
+    NULL);
 }
 
 
