@@ -2264,8 +2264,13 @@ run (void *cls,
     return;
   }
 
+  /* TODO: Load config variables for merchant token family
+           cipher type "rsa" or "cs" and key size.
+           Defaults to "rsa" and 2048 bits. */
+
   if (GNUNET_OK !=
       TALER_CONFIG_parse_currencies (cfg,
+                                     TMH_currency,
                                      &TMH_num_cspecs,
                                      &TMH_cspecs))
   {
