@@ -410,7 +410,8 @@ struct TMH_HandlerContext;
 /**
  * Possible authorization scopes. This is a bit mask.
  */
-enum TMH_AuthScope {
+enum TMH_AuthScope
+{
   /**
    * Nothing is authorized.
    */
@@ -587,6 +588,11 @@ struct TMH_HandlerContext
    */
   const char *url;
 
+  /**
+   * Copy of our original full URL with query parameters.
+   */
+  char *full_url;
+
   /**
    * Client-provided authentication token for this
    * request, can be NULL.
@@ -671,6 +677,23 @@ struct TMH_SuspendedConnection
  */
 extern char *TMH_currency;
 
+/**
+ * What is the base URL for this merchant backend?  NULL if it is not
+ * configured and is to be determined from HTTP headers (X-Forwarded-Host and
+ * X-Forwarded-Port and X-Forwarded-Prefix) of the reverse proxy.
+ */
+extern char *TMH_base_url;
+
+/**
+ * Length of the TMH_cspecs array.
+ */
+extern unsigned int TMH_num_cspecs;
+
+/**
+ * Rendering specs for currencies.
+ */
+extern struct TALER_CurrencySpecification *TMH_cspecs;
+
 /**
  * Inform the auditor for all deposit confirmations (global option)
  */
