@@ -24,11 +24,12 @@
 #include <stdint.h>
 #include "taler-merchant-httpd_contract.h"
 
+
 enum TALER_MerchantContractInputType
 TMH_contract_input_type_from_string (const char *str)
 {
   /* For now, only 'token' is the only supported option. */
-  if (0 == strcmp("token", str))
+  if (0 == strcmp ("token", str))
   {
     return TALER_MCIT_TOKEN;
   }
@@ -36,22 +37,24 @@ TMH_contract_input_type_from_string (const char *str)
   return TALER_MCIT_INVALID;
 }
 
+
 enum TALER_MerchantContractOutputType
 TMH_contract_output_type_from_string (const char *str)
 {
   /* For now, only 'token' is the only supported option. */
-  if (0 == strcmp("token", str))
+  if (0 == strcmp ("token", str))
   {
     return TALER_MCOT_TOKEN;
   }
-
   return TALER_MCOT_INVALID;
 }
 
+
 const char *
 TMH_string_from_contract_input_type (enum TALER_MerchantContractInputType t)
 {
-  switch (t) {
+  switch (t)
+  {
   case TALER_MCIT_TOKEN:
     return "token";
   case TALER_MCIT_COIN:
@@ -61,10 +64,12 @@ TMH_string_from_contract_input_type (enum TALER_MerchantContractInputType t)
   }
 }
 
+
 const char *
 TMH_string_from_contract_output_type (enum TALER_MerchantContractOutputType t)
 {
-  switch (t) {
+  switch (t)
+  {
   case TALER_MCOT_TOKEN:
     return "token";
   case TALER_MCOT_COIN:
@@ -76,22 +81,24 @@ TMH_string_from_contract_output_type (enum TALER_MerchantContractOutputType t)
   }
 }
 
+
 /**
  * Parse given JSON object to choices array.
  *
  * @param cls closure, pointer to array length
  * @param root the json array representing the choices
- * @param[out] spec where to write the data
+ * @param[out] ospec where to write the data
  * @return #GNUNET_OK upon successful parsing; #GNUNET_SYSERR upon error
  */
 static enum GNUNET_GenericReturnValue
 parse_choices (void *cls,
-              json_t *root,
-              struct GNUNET_JSON_Specification *spec)
+               json_t *root,
+               struct GNUNET_JSON_Specification *ospec)
 {
-  struct TALER_MerchantContractChoice **choices = spec->ptr;
+  struct TALER_MerchantContractChoice **choices = ospec->ptr;
   unsigned int *choices_len = cls;
-  if (!json_is_array (root))
+
+  if (! json_is_array (root))
   {
     GNUNET_break_op (0);
     return GNUNET_SYSERR;
@@ -118,9 +125,9 @@ parse_choices (void *cls,
 
     if (GNUNET_OK !=
         GNUNET_JSON_parse (json_array_get (root, i),
-                          spec,
-                          &error_name,
-                          &error_line))
+                           spec,
+                           &error_name,
+                           &error_line))
     {
       GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                   "Failed to parse %s at %u: %s\n",
@@ -140,29 +147,29 @@ parse_choices (void *cls,
         const char *kind;
         struct GNUNET_JSON_Specification ispec[] = {
           GNUNET_JSON_spec_string ("kind",
-                                    &kind),
+                                   &kind),
           GNUNET_JSON_spec_string ("token_family_slug",
-                                    &input.details.token.token_family_slug),
+                                   &input.details.token.token_family_slug),
           GNUNET_JSON_spec_timestamp ("valid_after",
                                       &input.details.token.valid_after),
           GNUNET_JSON_spec_mark_optional (
             GNUNET_JSON_spec_uint32 ("count",
-                                      &input.details.token.count),
+                                     &input.details.token.count),
             NULL),
-          GNUNET_JSON_spec_end()
+          GNUNET_JSON_spec_end ()
         };
         const char *ierror_name;
         unsigned int ierror_line;
 
         if (GNUNET_OK !=
             GNUNET_JSON_parse (jinput,
-                                ispec,
-                                &ierror_name,
-                                &ierror_line))
+                               ispec,
+                               &ierror_name,
+                               &ierror_line))
         {
           GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                       "Failed to parse %s at %u: %s\n",
-                      spec[ierror_line].field,
+                      ispec[ierror_line].field,
                       ierror_line,
                       ierror_name);
           GNUNET_break_op (0);
@@ -197,33 +204,35 @@ parse_choices (void *cls,
       size_t idx;
       json_array_foreach ((json_t *) joutputs, idx, joutput)
       {
-        struct TALER_MerchantContractOutput output = {.details.token.count = 1};
+        struct TALER_MerchantContractOutput output = {
+          .details.token.count = 1
+        };
         const char *kind;
         struct GNUNET_JSON_Specification ispec[] = {
           GNUNET_JSON_spec_string ("kind",
-                                    &kind),
+                                   &kind),
           GNUNET_JSON_spec_string ("token_family_slug",
-                                    &output.details.token.token_family_slug),
+                                   &output.details.token.token_family_slug),
           GNUNET_JSON_spec_timestamp ("valid_after",
                                       &output.details.token.valid_after),
           GNUNET_JSON_spec_mark_optional (
             GNUNET_JSON_spec_uint32 ("count",
-                                      &output.details.token.count),
+                                     &output.details.token.count),
             NULL),
-          GNUNET_JSON_spec_end()
+          GNUNET_JSON_spec_end ()
         };
         const char *ierror_name;
         unsigned int ierror_line;
 
         if (GNUNET_OK !=
             GNUNET_JSON_parse (joutput,
-                                ispec,
-                                &ierror_name,
-                                &ierror_line))
+                               ispec,
+                               &ierror_name,
+                               &ierror_line))
         {
           GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                       "Failed to parse %s at %u: %s\n",
-                      spec[ierror_line].field,
+                      ispec[ierror_line].field,
                       ierror_line,
                       ierror_name);
           GNUNET_break_op (0);
@@ -253,7 +262,6 @@ parse_choices (void *cls,
       }
     }
   }
-
   return GNUNET_OK;
 }
 
@@ -280,25 +288,25 @@ TALER_JSON_spec_choices (const char *name,
  * @param cls closure, pointer to array length
  * @param root the json object representing the token families. The keys are
  *             the token family slugs.
- * @param[out] spec where to write the data
+ * @param[out] ospec where to write the data
  * @return #GNUNET_OK upon successful parsing; #GNUNET_SYSERR upon error
  */
 static enum GNUNET_GenericReturnValue
 parse_token_families (void *cls,
                       json_t *root,
-                      struct GNUNET_JSON_Specification *spec)
+                      struct GNUNET_JSON_Specification *ospec)
 {
-  struct TALER_MerchantContractTokenFamily **families = spec->ptr;
+  struct TALER_MerchantContractTokenFamily **families = ospec->ptr;
   unsigned int *families_len = cls;
   json_t *jfamily;
   const char *slug;
-  if (!json_is_object (root))
+
+  if (! json_is_object (root))
   {
     GNUNET_break_op (0);
     return GNUNET_SYSERR;
   }
-
-  json_object_foreach(root, slug, jfamily)
+  json_object_foreach (root, slug, jfamily)
   {
     const json_t *keys;
     struct TALER_MerchantContractTokenFamily family = {
@@ -307,9 +315,9 @@ parse_token_families (void *cls,
 
     struct GNUNET_JSON_Specification spec[] = {
       GNUNET_JSON_spec_array_const ("keys",
-                                     &keys),
+                                    &keys),
       GNUNET_JSON_spec_bool ("critical",
-                              &family.critical),
+                             &family.critical),
       GNUNET_JSON_spec_end ()
       /* TODO: Figure out if these fields should be 'const' */
       // GNUNET_JSON_spec_string ("description",
@@ -322,9 +330,9 @@ parse_token_families (void *cls,
 
     if (GNUNET_OK !=
         GNUNET_JSON_parse (jfamily,
-                          spec,
-                          &error_name,
-                          &error_line))
+                           spec,
+                           &error_name,
+                           &error_line))
     {
       GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                   "Failed to parse %s at %u: %s\n",
@@ -343,44 +351,55 @@ parse_token_families (void *cls,
     {
       /* TODO: Move this to TALER_JSON_spec_token_issue_key */
       int64_t cipher;
-      struct TALER_MerchantContractTokenFamilyKey *key;
-      key = &family.keys[i];
+      struct TALER_MerchantContractTokenFamilyKey *key = &family.keys[i];
       /* TODO: Free when not used anymore */
-      key->pub.public_key = GNUNET_new (struct GNUNET_CRYPTO_BlindSignPublicKey);
-      struct GNUNET_JSON_Specification key_spec[] = {
-        GNUNET_JSON_spec_fixed_auto ("h_pub",
-                                   &key->pub.public_key->pub_key_hash),
-        GNUNET_JSON_spec_rsa_public_key ("rsa_pub",
-                                         &key->pub.public_key->details.rsa_public_key),
-        //   GNUNET_JSON_spec_fixed_auto ("cs_pub",
-        //                               &key.pub.public_key->details.cs_public_key)),
-        GNUNET_JSON_spec_int64 ("cipher",
-                                &cipher),
-        GNUNET_JSON_spec_timestamp ("valid_after",
-                                    &key->valid_after),
-        GNUNET_JSON_spec_timestamp ("valid_before",
-                                    &key->valid_before),
-        GNUNET_JSON_spec_end()
-      };
-      const char *ierror_name;
-      unsigned int ierror_line;
 
-      if (GNUNET_OK !=
-          GNUNET_JSON_parse (json_array_get (keys, i),
-                             key_spec,
-                             &ierror_name,
-                             &ierror_line))
+      key->pub.public_key
+        = GNUNET_new (struct GNUNET_CRYPTO_BlindSignPublicKey);
       {
-        GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                    "Failed to parse %s at %u: %s\n",
-                    key_spec[ierror_line].field,
-                    ierror_line,
-                    ierror_name);
-        GNUNET_break_op (0);
-        return GNUNET_SYSERR;
+        struct GNUNET_JSON_Specification key_spec[] = {
+          GNUNET_JSON_spec_fixed_auto (
+            "h_pub",
+            &key->pub.public_key->pub_key_hash),
+          GNUNET_JSON_spec_rsa_public_key (
+            "rsa_pub",
+            &key->pub.public_key->details.rsa_public_key),
+          // FIXME: sort out CS here!
+          //   GNUNET_JSON_spec_fixed_auto ("cs_pub",
+          //                               &key.pub.public_key->details.cs_public_key)),
+          GNUNET_JSON_spec_int64 (
+            "cipher",
+            &cipher),
+          GNUNET_JSON_spec_timestamp (
+            "valid_after",
+            &key->valid_after),
+          GNUNET_JSON_spec_timestamp (
+            "valid_before",
+            &key->valid_before),
+          GNUNET_JSON_spec_end ()
+        };
+        const char *ierror_name;
+        unsigned int ierror_line;
+
+        if (GNUNET_OK !=
+            GNUNET_JSON_parse (json_array_get (keys,
+                                               i),
+                               key_spec,
+                               &ierror_name,
+                               &ierror_line))
+        {
+          GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                      "Failed to parse %s at %u: %s\n",
+                      key_spec[ierror_line].field,
+                      ierror_line,
+                      ierror_name);
+          GNUNET_break_op (0);
+          return GNUNET_SYSERR;
+        }
       }
 
-      switch (cipher) {
+      switch (cipher)
+      {
       case GNUNET_CRYPTO_BSA_RSA:
         key->pub.public_key->cipher = GNUNET_CRYPTO_BSA_RSA;
         break;
@@ -395,8 +414,9 @@ parse_token_families (void *cls,
         return GNUNET_SYSERR;
       }
     }
-
-    GNUNET_array_append (*families, *families_len, family);
+    GNUNET_array_append (*families,
+                         *families_len,
+                         family);
   }
 
   return GNUNET_OK;
@@ -404,9 +424,10 @@ parse_token_families (void *cls,
 
 
 struct GNUNET_JSON_Specification
-TALER_JSON_spec_token_families (const char *name,
-                                struct TALER_MerchantContractTokenFamily **families,
-                                unsigned int *families_len)
+TALER_JSON_spec_token_families (
+  const char *name,
+  struct TALER_MerchantContractTokenFamily **families,
+  unsigned int *families_len)
 {
   struct GNUNET_JSON_Specification ret = {
     .cls = (void *) families_len,
@@ -418,34 +439,36 @@ TALER_JSON_spec_token_families (const char *name,
   return ret;
 }
 
+
 enum GNUNET_GenericReturnValue
-TMH_find_token_family_key (const char *slug,
-                           struct GNUNET_TIME_Timestamp valid_after,
-                           struct TALER_MerchantContractTokenFamily *families,
-                           unsigned int families_len,
-                           struct TALER_MerchantContractTokenFamily *family,
-                           struct TALER_MerchantContractTokenFamilyKey *key)
+TMH_find_token_family_key (
+  const char *slug,
+  struct GNUNET_TIME_Timestamp valid_after,
+  const struct TALER_MerchantContractTokenFamily *families,
+  unsigned int families_len,
+  struct TALER_MerchantContractTokenFamily *family,
+  struct TALER_MerchantContractTokenFamilyKey *key)
 {
   for (unsigned int i = 0; i < families_len; i++)
   {
-    if (0 != strcmp (families[i].slug, slug))
-    {
+    const struct TALER_MerchantContractTokenFamily *fami
+      = &families[i];
+
+    if (0 != strcmp (fami->slug,
+                     slug))
       continue;
-    }
     if (NULL != family)
+      *family = *fami;
+    for (unsigned int k = 0; k < fami->keys_len; k++)
     {
-      *family = families[i];
-    }
-    for (unsigned int k = 0; k < family->keys_len; k++)
-    {
-      if (GNUNET_TIME_timestamp_cmp(family->keys[k].valid_after,
-                                    ==,
-                                    valid_after))
+      struct TALER_MerchantContractTokenFamilyKey *ki = &fami->keys[k];
+
+      if (GNUNET_TIME_timestamp_cmp (ki->valid_after,
+                                     ==,
+                                     valid_after))
       {
         if (NULL != key)
-        {
-          *key = family->keys[k];
-        }
+          *key = *ki;
         return GNUNET_OK;
       }
     }
@@ -455,4 +478,4 @@ TMH_find_token_family_key (const char *slug,
 
   /* no matching family found */
   return GNUNET_NO;
-}
\ No newline at end of file
+}
