@@ -472,9 +472,13 @@ resume_by_event (void *cls,
     }
   }
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-              "Resuming (%d/%d) by event with argument `%.*s`\n",
-              (int) GNUNET_TIME_absolute_is_future (god->sc.long_poll_timeout),
-              god->sc.awaiting_refund,
+              "Resuming (%s/%s) by event with argument `%.*s`\n",
+              GNUNET_TIME_absolute_is_future (god->sc.long_poll_timeout)
+              ? "future"
+              : "past",
+              god->sc.awaiting_refund
+              ? "awaiting refund"
+              : "not waiting for refund",
               (int) extra_size,
               (const char *) extra);
   god->suspended = GNUNET_NO;
@@ -566,37 +570,41 @@ phase_lookup_terms (struct GetOrderData *god)
 {
   uint64_t order_serial;
   struct TALER_ClaimTokenP db_claim_token;
-  enum GNUNET_DB_QueryStatus qs;
 
   /* Convert order_id to h_contract_terms */
   TMH_db->preflight (TMH_db->cls);
   GNUNET_assert (NULL == god->contract_terms);
-  qs = TMH_db->lookup_contract_terms (
-    TMH_db->cls,
-    god->hc->instance->settings.id,
-    god->order_id,
-    &god->contract_terms,
-    &order_serial,
-    &db_claim_token);
-  if (0 > qs)
+
   {
-    /* single, read-only SQL statements should never cause
-       serialization problems */
-    GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR != qs);
-    /* Always report on hard error as well to enable diagnostics */
-    GNUNET_break (0);
-    phase_fail (god,
-                MHD_HTTP_INTERNAL_SERVER_ERROR,
-                TALER_EC_GENERIC_DB_FETCH_FAILED,
-                "lookup_contract_terms");
-    return;
+    enum GNUNET_DB_QueryStatus qs;
+
+    qs = TMH_db->lookup_contract_terms (
+      TMH_db->cls,
+      god->hc->instance->settings.id,
+      god->order_id,
+      &god->contract_terms,
+      &order_serial,
+      &db_claim_token);
+    if (0 > qs)
+    {
+      /* single, read-only SQL statements should never cause
+         serialization problems */
+      GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR != qs);
+      /* Always report on hard error as well to enable diagnostics */
+      GNUNET_break (0);
+      phase_fail (god,
+                  MHD_HTTP_INTERNAL_SERVER_ERROR,
+                  TALER_EC_GENERIC_DB_FETCH_FAILED,
+                  "lookup_contract_terms");
+      return;
+    }
+    /* Note: when "!ord.requireClaimToken" and the client does not provide
+       a claim token (all zeros!), then token_match==TRUE below: */
+    god->token_match
+      = (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT == qs)
+        && (0 == GNUNET_memcmp (&db_claim_token,
+                                &god->claim_token));
   }
-  /* Note: when "!ord.requireClaimToken" and the client does not provide
-     a claim token (all zeros!), then token_match==TRUE below: */
-  god->token_match
-    = (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT == qs)
-      && (0 == GNUNET_memcmp (&db_claim_token,
-                              &god->claim_token));
 
   /* Check if client provided the right hash code of the contract terms */
   if (NULL != god->contract_terms)
@@ -653,7 +661,6 @@ phase_lookup_terms (struct GetOrderData *god)
   }
   else
   {
-    struct TALER_ClaimTokenP db_claim_token;
     struct TALER_MerchantPostDataHashP unused;
     enum GNUNET_DB_QueryStatus qs;
 
@@ -988,8 +995,6 @@ send_pay_request (struct GetOrderData *god,
                                              MHD_HTTP_HEADER_LOCATION,
                                              god->fulfillment_url));
       {
-        MHD_RESULT ret;
-
         ret = MHD_queue_response (god->sc.con,
                                   MHD_HTTP_FOUND,
                                   reply);
