@@ -97,7 +97,7 @@ TMH_cmp_wire_account (
 bool
 TMH_accounts_array_valid (const json_t *accounts)
 {
-  unsigned int len;
+  size_t len;
 
   if (! json_is_array (accounts))
   {
@@ -105,7 +105,7 @@ TMH_accounts_array_valid (const json_t *accounts)
     return false;
   }
   len = json_array_size (accounts);
-  for (unsigned int i = 0; i<len; i++)
+  for (size_t i = 0; i<len; i++)
   {
     json_t *payto_uri = json_array_get (accounts,
                                         i);
