@@ -134,14 +134,12 @@ TMH_post_orders_ID_paid (const struct TMH_RequestHandler *rh,
   TMH_db->preflight (TMH_db->cls);
   {
     uint64_t order_serial;
-    bool paid;
 
     qs = TMH_db->lookup_contract_terms (TMH_db->cls,
                                         hc->instance->settings.id,
                                         order_id,
                                         &contract_terms,
                                         &order_serial,
-                                        &paid,
                                         NULL);
   }
   if (0 > qs)
