@@ -1,6 +1,6 @@
 /*
   This file is part of GNU Taler
-  (C) 2021-2023 Taler Systems SA
+  (C) 2021-2024 Taler Systems SA
 
   GNU Taler is free software; you can redistribute it and/or modify
   it under the terms of the GNU Affero General Public License as
@@ -455,9 +455,8 @@ ekr_finished (struct ExchangeKycRequest *ekr)
        after we asked at the exchanges => 204 */
     struct MHD_Response *response;
 
-    response = MHD_create_response_from_buffer (0,
-                                                "",
-                                                MHD_RESPMEM_PERSISTENT);
+    response = MHD_create_response_from_buffer_static (0,
+                                                       "");
     resume_kyc_with_response (kc,
                               MHD_HTTP_NO_CONTENT,
                               response);
@@ -474,6 +473,78 @@ ekr_finished (struct ExchangeKycRequest *ekr)
 }
 
 
+/**
+ * Store KYC response from the exchange in the
+ * local database.
+ *
+ * @param ekr request context
+ * @param ks HTTP response details
+ * @param account_kyc_status account KYC status details
+ * @return true if the operation was successful
+ */
+static bool
+store_kyc_status (
+  const struct ExchangeKycRequest *ekr,
+  const struct TALER_EXCHANGE_KycStatus *ks,
+  const struct TALER_EXCHANGE_AccountKycStatus *account_kyc_status)
+{
+  unsigned int dl_cnt = 0;
+
+  for (unsigned int i = 0; i<account_kyc_status->limits_length; i++)
+  {
+    const struct TALER_EXCHANGE_AccountLimit *limit
+      = &account_kyc_status->limits[i];
+
+    if (TALER_KYCLOGIC_KYC_TRIGGER_DEPOSIT ==
+        limit->operation_type)
+      dl_cnt++;
+  }
+
+  {
+    struct TALER_MERCHANTDB_DepositLimits dls[GNUNET_NZL (dl_cnt)];
+    enum GNUNET_DB_QueryStatus qs;
+    unsigned int off = 0;
+
+    for (unsigned int i = 0; i<account_kyc_status->limits_length; i++)
+    {
+      const struct TALER_EXCHANGE_AccountLimit *limit
+        = &account_kyc_status->limits[i];
+      struct TALER_MERCHANTDB_DepositLimits *dl
+        = &dls[off];
+
+      if (TALER_KYCLOGIC_KYC_TRIGGER_DEPOSIT !=
+          limit->operation_type)
+        continue;
+      dl->timeframe = limit->timeframe;
+      dl->threshold = limit->threshold;
+      dl->soft_limit = limit->soft_limit;
+      off++;
+    }
+    qs = TMH_db->account_kyc_set_status (
+      TMH_db->cls,
+      ekr->kc->mi->settings.id,
+      &ekr->h_wire,
+      ekr->exchange_url,
+      ekr->exchange_kyc_serial,
+      GNUNET_TIME_timestamp_get (),
+      ks->hr.http_status,
+      ks->hr.ec,
+      &account_kyc_status->access_token,
+      dl_cnt,
+      dls,
+      account_kyc_status->aml_review,
+      false);
+    if (qs < 0)
+    {
+      GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                  "Failed to store KYC status in database!\n");
+      return false;
+    }
+  }
+  return true;
+}
+
+
 /**
  * Function called with the result of a KYC check.
  *
@@ -481,104 +552,76 @@ ekr_finished (struct ExchangeKycRequest *ekr)
  * @param ks the account's KYC status details
  */
 static void
-exchange_check_cb (void *cls,
-                   const struct TALER_EXCHANGE_KycStatus *ks)
+exchange_check_cb (
+  void *cls,
+  const struct TALER_EXCHANGE_KycStatus *ks)
 {
   struct ExchangeKycRequest *ekr = cls;
   struct KycContext *kc = ekr->kc;
 
   ekr->kyc = NULL;
-  switch (ks->http_status)
+  switch (ks->hr.http_status)
   {
   case MHD_HTTP_OK:
-    {
-      enum GNUNET_DB_QueryStatus qs;
-
-      if (TALER_AML_NORMAL != ks->details.ok.aml_status)
-      {
-        GNUNET_assert (
-          0 ==
-          json_array_append_new (
-            kc->pending_kycs,
-            GNUNET_JSON_PACK (
-              GNUNET_JSON_pack_uint64 (
-                "aml_status",
-                ks->details.ok.aml_status),
-              GNUNET_JSON_pack_string ("exchange_url",
-                                       ekr->exchange_url),
-              GNUNET_JSON_pack_string ("payto_uri",
-                                       ekr->payto_uri))));
-      }
-      qs = TMH_db->account_kyc_set_status (TMH_db->cls,
-                                           kc->mi->settings.id,
-                                           &ekr->h_wire,
-                                           ekr->exchange_url,
-                                           ekr->exchange_kyc_serial,
-                                           &ks->details.ok.exchange_sig,
-                                           &ks->details.ok.exchange_pub,
-                                           ks->details.ok.timestamp,
-                                           true, /* KYC OK */
-                                           ks->details.ok.aml_status);
-      if (qs < 0)
-      {
-        GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                    "Failed to store KYC status in database!\n");
-      }
-    }
+    GNUNET_break (store_kyc_status (ekr,
+                                    ks,
+                                    &ks->details.ok));
     break;
   case MHD_HTTP_ACCEPTED:
     {
-      struct GNUNET_TIME_Timestamp now;
-      enum GNUNET_DB_QueryStatus qs;
+      const struct TALER_EXCHANGE_AccountKycStatus *account_kyc_status
+        = &ks->details.accepted;
+      char *kyc_url;
 
+      GNUNET_break (store_kyc_status (ekr,
+                                      ks,
+                                      account_kyc_status));
+      {
+        char *ats;
+
+        ats = GNUNET_STRINGS_data_to_string_alloc (
+          &account_kyc_status->access_token,
+          sizeof (account_kyc_status->access_token));
+        GNUNET_asprintf (&kyc_url,
+                         "%s/kyc-spa/%s",
+                         ekr->exchange_url,
+                         ats);
+        GNUNET_free (ats);
+      }
       GNUNET_assert (
         0 ==
         json_array_append_new (
           kc->pending_kycs,
           GNUNET_JSON_PACK (
+            GNUNET_JSON_pack_data_auto ("access_token",
+                                        &account_kyc_status->access_token),
             GNUNET_JSON_pack_string ("kyc_url",
-                                     ks->details.accepted.kyc_url),
-            GNUNET_JSON_pack_uint64 ("aml_status",
-                                     ks->details.accepted.aml_status),
+                                     kyc_url),
             GNUNET_JSON_pack_string ("exchange_url",
                                      ekr->exchange_url),
             GNUNET_JSON_pack_string ("payto_uri",
                                      ekr->payto_uri))));
-      now = GNUNET_TIME_timestamp_get ();
-      qs = TMH_db->account_kyc_set_status (
-        TMH_db->cls,
-        kc->mi->settings.id,
-        &ekr->h_wire,
-        ekr->exchange_url,
-        ekr->exchange_kyc_serial,
-        NULL,
-        NULL,
-        now,
-        false, /* KYC not OK */
-        ks->details.accepted.aml_status);
-      if (qs < 0)
-      {
-        GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                    "Failed to store KYC status in database!\n");
-      }
+      GNUNET_free (kyc_url);
       break;
     }
   case MHD_HTTP_NO_CONTENT:
     {
-      struct GNUNET_TIME_Timestamp now;
       enum GNUNET_DB_QueryStatus qs;
 
-      now = GNUNET_TIME_timestamp_get ();
-      qs = TMH_db->account_kyc_set_status (TMH_db->cls,
-                                           kc->mi->settings.id,
-                                           &ekr->h_wire,
-                                           ekr->exchange_url,
-                                           ekr->exchange_kyc_serial,
-                                           NULL,
-                                           NULL,
-                                           now,
-                                           true, /* KYC OK */
-                                           TALER_AML_NORMAL);
+      qs = TMH_db->account_kyc_set_status (
+        TMH_db->cls,
+        kc->mi->settings.id,
+        &ekr->h_wire,
+        ekr->exchange_url,
+        ekr->exchange_kyc_serial,
+        GNUNET_TIME_timestamp_get (),
+        MHD_HTTP_NO_CONTENT,
+        TALER_EC_NONE,
+        NULL,
+        0,
+        NULL,
+        false,
+        true);
       if (qs < 0)
       {
         GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
@@ -586,35 +629,38 @@ exchange_check_cb (void *cls,
       }
     }
     break;
-  case MHD_HTTP_UNAVAILABLE_FOR_LEGAL_REASONS:
+  case MHD_HTTP_FORBIDDEN:
+  case MHD_HTTP_NOT_FOUND:
+  case MHD_HTTP_CONFLICT:
+  case MHD_HTTP_UNAVAILABLE_FOR_LEGAL_REASONS: // FIXME: real?
     {
-      struct GNUNET_TIME_Timestamp now;
       enum GNUNET_DB_QueryStatus qs;
 
       GNUNET_assert (
         0 ==
         json_array_append_new (
-          kc->pending_kycs,
+          kc->timeout_kycs,
           GNUNET_JSON_PACK (
-            GNUNET_JSON_pack_uint64 (
-              "aml_status",
-              ks->details.unavailable_for_legal_reasons.aml_status),
             GNUNET_JSON_pack_string ("exchange_url",
                                      ekr->exchange_url),
-            GNUNET_JSON_pack_string ("payto_uri",
-                                     ekr->payto_uri))));
-      now = GNUNET_TIME_timestamp_get ();
+            GNUNET_JSON_pack_uint64 ("exchange_code",
+                                     ks->hr.ec),
+            GNUNET_JSON_pack_uint64 ("exchange_http_status",
+                                     ks->hr.http_status))));
       qs = TMH_db->account_kyc_set_status (
         TMH_db->cls,
         kc->mi->settings.id,
         &ekr->h_wire,
         ekr->exchange_url,
         ekr->exchange_kyc_serial,
+        GNUNET_TIME_timestamp_get (),
+        ks->hr.http_status,
+        ks->hr.ec,
         NULL,
+        0,
         NULL,
-        now,
-        true, /* KYC is OK, AML not... */
-        ks->details.unavailable_for_legal_reasons.aml_status);
+        false,
+        true);
       if (qs < 0)
       {
         GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
@@ -623,22 +669,46 @@ exchange_check_cb (void *cls,
     }
     break;
   default:
-    GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                "Exchange responded with HTTP status %u (%d) to /kyc-check request!\n",
-                ks->http_status,
-                ks->ec);
-    kc->response_code = MHD_HTTP_BAD_GATEWAY;
-    GNUNET_assert (
-      0 ==
-      json_array_append_new (
-        kc->timeout_kycs,
-        GNUNET_JSON_PACK (
-          GNUNET_JSON_pack_string ("exchange_url",
-                                   ekr->exchange_url),
-          GNUNET_JSON_pack_uint64 ("exchange_code",
-                                   ks->ec),
-          GNUNET_JSON_pack_uint64 ("exchange_http_status",
-                                   ks->http_status))));
+    {
+      enum GNUNET_DB_QueryStatus qs;
+
+      GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                  "Exchange responded with HTTP status %u (%d) to /kyc-check request!\n",
+                  ks->hr.http_status,
+                  ks->hr.ec);
+      kc->response_code = MHD_HTTP_BAD_GATEWAY;
+      GNUNET_assert (
+        0 ==
+        json_array_append_new (
+          kc->timeout_kycs,
+          GNUNET_JSON_PACK (
+            GNUNET_JSON_pack_string ("exchange_url",
+                                     ekr->exchange_url),
+            GNUNET_JSON_pack_uint64 ("exchange_code",
+                                     ks->hr.ec),
+            GNUNET_JSON_pack_uint64 ("exchange_http_status",
+                                     ks->hr.http_status))));
+      qs = TMH_db->account_kyc_set_status (
+        TMH_db->cls,
+        kc->mi->settings.id,
+        &ekr->h_wire,
+        ekr->exchange_url,
+        ekr->exchange_kyc_serial,
+        GNUNET_TIME_timestamp_get (),
+        ks->hr.http_status,
+        ks->hr.ec,
+        NULL,
+        0,
+        NULL,
+        false,
+        true);
+      if (qs < 0)
+      {
+        GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                    "Failed to store KYC status in database!\n");
+      }
+      break;
+    }
   }
   ekr_finished (ekr);
 }
@@ -660,6 +730,7 @@ kyc_with_exchange (void *cls,
   struct ExchangeKycRequest *ekr = cls;
   struct KycContext *kc = ekr->kc;
   struct TALER_PaytoHashP h_payto;
+  union TALER_AccountPrivateKeyP ap;
 
   (void) exchange;
   ekr->fo = NULL;
@@ -678,13 +749,12 @@ kyc_with_exchange (void *cls,
   }
   TALER_payto_hash (ekr->payto_uri,
                     &h_payto);
+  ap.merchant_priv = kc->mi->merchant_priv;
   ekr->kyc = TALER_EXCHANGE_kyc_check (
     TMH_curl_ctx,
     ekr->exchange_url,
-    keys,
     ekr->exchange_kyc_serial,
-    &h_payto,
-    1, /* FIXME: this will go away! */
+    &ap,
     GNUNET_TIME_absolute_get_remaining (kc->timeout),
     &exchange_check_cb,
     ekr);
@@ -702,23 +772,21 @@ kyc_with_exchange (void *cls,
  * @param exchange_url base URL of the exchange for which this is a status
  * @param last_check when did we last get an update on our KYC status from the exchange
  * @param kyc_ok true if we satisfied the KYC requirements
- * @param aml_decision latest AML decision known to us
  */
 static void
-kyc_status_cb (void *cls,
-               const struct TALER_MerchantWireHashP *h_wire,
-               uint64_t exchange_kyc_serial,
-               const char *payto_uri,
-               const char *exchange_url,
-               struct GNUNET_TIME_Timestamp last_check,
-               bool kyc_ok,
-               enum TALER_AmlDecisionState aml_decision)
+kyc_status_cb (
+  void *cls,
+  const struct TALER_MerchantWireHashP *h_wire,
+  uint64_t exchange_kyc_serial,
+  const char *payto_uri,
+  const char *exchange_url,
+  struct GNUNET_TIME_Timestamp last_check,
+  bool kyc_ok)
 {
   struct KycContext *kc = cls;
   struct ExchangeKycRequest *ekr;
 
   if (kyc_ok &&
-      (TALER_AML_PENDING != aml_decision) &&
       (GNUNET_TIME_relative_cmp (
          GNUNET_TIME_absolute_get_duration (last_check.abs_time),
          <,
@@ -740,10 +808,11 @@ kyc_status_cb (void *cls,
   ekr->payto_uri = GNUNET_strdup (payto_uri);
   ekr->last_check = last_check;
   ekr->kc = kc;
-  ekr->fo = TMH_EXCHANGES_keys4exchange (exchange_url,
-                                         false,
-                                         &kyc_with_exchange,
-                                         ekr);
+  ekr->fo = TMH_EXCHANGES_keys4exchange (
+    exchange_url,
+    false,
+    &kyc_with_exchange,
+    ekr);
 }
 
 
@@ -756,9 +825,10 @@ kyc_status_cb (void *cls,
  * @return MHD result code
  */
 static MHD_RESULT
-get_instances_ID_kyc (struct TMH_MerchantInstance *mi,
-                      struct MHD_Connection *connection,
-                      struct TMH_HandlerContext *hc)
+get_instances_ID_kyc (
+  struct TMH_MerchantInstance *mi,
+  struct MHD_Connection *connection,
+  struct TMH_HandlerContext *hc)
 {
   struct KycContext *kc = hc->ctx;
 
@@ -787,9 +857,10 @@ get_instances_ID_kyc (struct TMH_MerchantInstance *mi,
                                    kc);
 
     /* process 'exchange_url' argument */
-    kc->exchange_url = MHD_lookup_connection_value (connection,
-                                                    MHD_GET_ARGUMENT_KIND,
-                                                    "exchange_url");
+    kc->exchange_url = MHD_lookup_connection_value (
+      connection,
+      MHD_GET_ARGUMENT_KIND,
+      "exchange_url");
     if ( (NULL != kc->exchange_url) &&
          (! TALER_url_valid_charset (kc->exchange_url) ||
           ( (0 != strncasecmp (kc->exchange_url,
@@ -800,10 +871,11 @@ get_instances_ID_kyc (struct TMH_MerchantInstance *mi,
                                strlen ("https://"))) ) ) )
     {
       GNUNET_break_op (0);
-      return TALER_MHD_reply_with_error (connection,
-                                         MHD_HTTP_BAD_REQUEST,
-                                         TALER_EC_GENERIC_PARAMETER_MALFORMED,
-                                         "exchange_url must be a valid HTTP(s) URL");
+      return TALER_MHD_reply_with_error (
+        connection,
+        MHD_HTTP_BAD_REQUEST,
+        TALER_EC_GENERIC_PARAMETER_MALFORMED,
+        "exchange_url must be a valid HTTP(s) URL");
     }
 
     TALER_MHD_parse_request_arg_auto (connection,
@@ -814,20 +886,22 @@ get_instances_ID_kyc (struct TMH_MerchantInstance *mi,
     {
       enum GNUNET_DB_QueryStatus qs;
 
-      qs = TMH_db->account_kyc_get_status (TMH_db->cls,
-                                           mi->settings.id,
-                                           kc->have_h_wire
-                                           ? &kc->h_wire
-                                           : NULL,
-                                           kc->exchange_url,
-                                           &kyc_status_cb,
-                                           kc);
+      qs = TMH_db->account_kyc_get_status (
+        TMH_db->cls,
+        mi->settings.id,
+        kc->have_h_wire
+        ? &kc->h_wire
+        : NULL,
+        kc->exchange_url,
+        &kyc_status_cb,
+        kc);
       if (qs < 0)
       {
         GNUNET_break (0);
-        return TALER_MHD_reply_with_ec (connection,
-                                        TALER_EC_GENERIC_DB_FETCH_FAILED,
-                                        "account_kyc_get_status");
+        return TALER_MHD_reply_with_ec (
+          connection,
+          TALER_EC_GENERIC_DB_FETCH_FAILED,
+          "account_kyc_get_status");
       }
     }
     if (kc->kyc_serial_pending)
@@ -874,9 +948,10 @@ get_instances_ID_kyc (struct TMH_MerchantInstance *mi,
 
 
 MHD_RESULT
-TMH_private_get_instances_ID_kyc (const struct TMH_RequestHandler *rh,
-                                  struct MHD_Connection *connection,
-                                  struct TMH_HandlerContext *hc)
+TMH_private_get_instances_ID_kyc (
+  const struct TMH_RequestHandler *rh,
+  struct MHD_Connection *connection,
+  struct TMH_HandlerContext *hc)
 {
   struct TMH_MerchantInstance *mi = hc->instance;
 
@@ -888,9 +963,10 @@ TMH_private_get_instances_ID_kyc (const struct TMH_RequestHandler *rh,
 
 
 MHD_RESULT
-TMH_private_get_instances_default_ID_kyc (const struct TMH_RequestHandler *rh,
-                                          struct MHD_Connection *connection,
-                                          struct TMH_HandlerContext *hc)
+TMH_private_get_instances_default_ID_kyc (
+  const struct TMH_RequestHandler *rh,
+  struct MHD_Connection *connection,
+  struct TMH_HandlerContext *hc)
 {
   struct TMH_MerchantInstance *mi;
 
@@ -898,10 +974,11 @@ TMH_private_get_instances_default_ID_kyc (const struct TMH_RequestHandler *rh,
   mi = TMH_lookup_instance (hc->infix);
   if (NULL == mi)
   {
-    return TALER_MHD_reply_with_error (connection,
-                                       MHD_HTTP_NOT_FOUND,
-                                       TALER_EC_MERCHANT_GENERIC_INSTANCE_UNKNOWN,
-                                       hc->infix);
+    return TALER_MHD_reply_with_error (
+      connection,
+      MHD_HTTP_NOT_FOUND,
+      TALER_EC_MERCHANT_GENERIC_INSTANCE_UNKNOWN,
+      hc->infix);
   }
   return get_instances_ID_kyc (mi,
                                connection,
