@@ -503,7 +503,7 @@ resume_by_event (void *cls,
     GNUNET_break (0);
     return;
   }
-  osf = (enum TMH_OrderStateFlags) ntohl (oce->order_state);
+  osf = (enum TMH_OrderStateFlags) (int) ntohl (oce->order_state);
   order_serial_id = GNUNET_ntohll (oce->order_serial_id);
   date = GNUNET_TIME_timestamp_ntoh (oce->execution_date);
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
