@@ -20,7 +20,7 @@
  */
 #include "platform.h"
 #include "taler-merchant-httpd_private-get-pos.h"
-
+#include <taler/taler_json_lib.h>
 
 /**
  * Closure for add_product().
@@ -43,8 +43,13 @@ struct Context
 /**
  * Add product details to our JSON array.
  *
- * @param ctx a `struct Context` with JSON arrays to build
+ * @param cls a `struct Context` with JSON arrays to build
+ * @param product_serial row ID of the product
  * @param product_id ID of the product
+ * @param pd full product details
+ * @param num_categories length of @a categories array
+ * @param categories array of categories the
+ *   product is in
  */
 static void
 add_product (void *cls,
