@@ -64,16 +64,11 @@ patch_instances_ID (struct TMH_MerchantInstance *mi,
 {
   struct TALER_MERCHANTDB_InstanceSettings is;
   const char *name;
-  const char *uts = "business";
   struct TMH_WireMethod *wm_head = NULL;
   struct TMH_WireMethod *wm_tail = NULL;
   struct GNUNET_JSON_Specification spec[] = {
     GNUNET_JSON_spec_string ("name",
                              &name),
-    GNUNET_JSON_spec_mark_optional (
-      GNUNET_JSON_spec_string ("user_type",
-                               &uts),
-      NULL),
     GNUNET_JSON_spec_mark_optional (
       GNUNET_JSON_spec_string ("website",
                                (const char **) &is.website),
@@ -115,19 +110,6 @@ patch_instances_ID (struct TMH_MerchantInstance *mi,
              ? MHD_YES
              : MHD_NO;
   }
-  if (NULL == uts)
-    uts = "business";
-  if (GNUNET_OK !=
-      TALER_KYCLOGIC_kyc_user_type_from_string (uts,
-                                                &is.ut))
-  {
-    GNUNET_break_op (0);
-    GNUNET_JSON_parse_free (spec);
-    return TALER_MHD_reply_with_error (connection,
-                                       MHD_HTTP_BAD_REQUEST,
-                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
-                                       "user_type");
-  }
   if (! TMH_location_object_valid (is.address))
   {
     GNUNET_break_op (0);
@@ -185,7 +167,6 @@ patch_instances_ID (struct TMH_MerchantInstance *mi,
     /* Check for equality of settings */
     if (! ( (0 == strcmp (mi->settings.name,
                           name)) &&
-            (mi->settings.ut == is.ut) &&
             ((mi->settings.email == is.email) ||
              (NULL != is.email && NULL != mi->settings.email &&
               0 == strcmp (mi->settings.email,
@@ -240,7 +221,6 @@ giveup:
   json_decref (mi->settings.jurisdiction);
   is.id = mi->settings.id;
   mi->settings = is;
-  // mi->settings.user_type = (enum TALER_KYCLOGIC_KycUserType) is.user_type;
   mi->settings.address = json_incref (mi->settings.address);
   mi->settings.jurisdiction = json_incref (mi->settings.jurisdiction);
   mi->settings.name = GNUNET_strdup (name);
