@@ -16,14 +16,13 @@
   License along with TALER; see the file COPYING.  If not,
   see <http://www.gnu.org/licenses/>
 */
-
 /**
  * @file taler-merchant-httpd_private-patch-orders-ID-forget.c
  * @brief implementing PATCH /orders/$ORDER_ID/forget request handling
  * @author Jonathan Buchanan
  */
 #include "platform.h"
-#include "taler-merchant-httpd_private-patch-instances-ID.h"
+#include "taler-merchant-httpd_private-patch-orders-ID-forget.h"
 #include <taler/taler_json_lib.h>
 
 
