@@ -112,10 +112,6 @@ TMH_private_patch_templates_ID (const struct TMH_RequestHandler *rh,
       NULL),
     GNUNET_JSON_spec_json ("template_contract",
                            &tp.template_contract),
-    GNUNET_JSON_spec_mark_optional (
-      GNUNET_JSON_spec_string ("required_currency",
-                               (const char **) &tp.required_currency),
-      NULL),
     GNUNET_JSON_spec_mark_optional (
       GNUNET_JSON_spec_json ("editable_defaults",
                              &tp.editable_defaults),
@@ -146,28 +142,6 @@ TMH_private_patch_templates_ID (const struct TMH_RequestHandler *rh,
                                        TALER_EC_GENERIC_PARAMETER_MALFORMED,
                                        "template_contract");
   }
-  if ( (NULL != tp.required_currency) &&
-       (GNUNET_OK !=
-        TALER_check_currency (tp.required_currency)) )
-  {
-    GNUNET_break_op (0);
-    GNUNET_JSON_parse_free (spec);
-    return TALER_MHD_reply_with_error (connection,
-                                       MHD_HTTP_BAD_REQUEST,
-                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
-                                       "required_currency");
-  }
-  if ( (NULL != tp.required_currency) &&
-       (NULL != json_object_get (tp.template_contract,
-                                 "amount")) )
-  {
-    GNUNET_break_op (0);
-    GNUNET_JSON_parse_free (spec);
-    return TALER_MHD_reply_with_error (connection,
-                                       MHD_HTTP_BAD_REQUEST,
-                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
-                                       "required_currency and contract::amount specified");
-  }
   if (NULL != tp.editable_defaults)
   {
     const char *key;
