@@ -109,7 +109,7 @@ TMH_private_post_account (const struct TMH_RequestHandler *rh,
       return TALER_MHD_reply_with_error (connection,
                                          MHD_HTTP_BAD_REQUEST,
                                          TALER_EC_GENERIC_PARAMETER_MALFORMED,
-                                         "credit_facade_credentials");
+                                         "credit_facade_url or credit_facade_credentials");
     }
     TALER_MERCHANT_BANK_auth_free (&auth);
   }
