@@ -121,9 +121,8 @@ TMH_private_post_orders_ID_refund (const struct TMH_RequestHandler *rh,
   struct TALER_Amount refund;
   const char *reason;
   struct GNUNET_JSON_Specification spec[] = {
-    TALER_JSON_spec_amount ("refund",
-                            TMH_currency,
-                            &refund),
+    TALER_JSON_spec_amount_any ("refund",
+                                &refund),
     GNUNET_JSON_spec_string ("reason",
                              &reason),
     GNUNET_JSON_spec_end ()
@@ -133,22 +132,59 @@ TMH_private_post_orders_ID_refund (const struct TMH_RequestHandler *rh,
   json_t *contract_terms;
   struct GNUNET_TIME_Timestamp timestamp;
 
+  {
+    enum GNUNET_GenericReturnValue res;
+
+    res = TALER_MHD_parse_json_data (connection,
+                                     hc->request_body,
+                                     spec);
+    if (GNUNET_OK != res)
+    {
+      return (GNUNET_NO == res)
+             ? MHD_YES
+             : MHD_NO;
+    }
+  }
+
   {
     enum GNUNET_DB_QueryStatus qs;
     uint64_t order_serial;
     struct GNUNET_TIME_Timestamp refund_deadline;
-    bool paid = false;
 
     qs = TMH_db->lookup_contract_terms (TMH_db->cls,
                                         hc->instance->settings.id,
                                         hc->infix,
                                         &contract_terms,
                                         &order_serial,
-                                        &paid,
                                         NULL);
-    if (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT == qs)
+    if (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT != qs)
     {
-      struct GNUNET_JSON_Specification spec[] = {
+      if (qs < 0)
+      {
+        GNUNET_break (0);
+        return TALER_MHD_reply_with_error (connection,
+                                           MHD_HTTP_INTERNAL_SERVER_ERROR,
+                                           TALER_EC_GENERIC_DB_FETCH_FAILED,
+                                           "lookup_contract_terms");
+      }
+      return TALER_MHD_reply_with_error (connection,
+                                         MHD_HTTP_NOT_FOUND,
+                                         TALER_EC_MERCHANT_GENERIC_ORDER_UNKNOWN,
+                                         hc->infix);
+    }
+    if (GNUNET_OK !=
+        TALER_JSON_contract_hash (contract_terms,
+                                  &h_contract))
+    {
+      GNUNET_break (0);
+      json_decref (contract_terms);
+      return TALER_MHD_reply_with_error (connection,
+                                         MHD_HTTP_INTERNAL_SERVER_ERROR,
+                                         TALER_EC_GENERIC_FAILED_COMPUTE_JSON_HASH,
+                                         "Could not hash contract terms");
+    }
+    {
+      struct GNUNET_JSON_Specification cspec[] = {
         GNUNET_JSON_spec_timestamp ("refund_deadline",
                                     &refund_deadline),
         GNUNET_JSON_spec_timestamp ("timestamp",
@@ -158,11 +194,10 @@ TMH_private_post_orders_ID_refund (const struct TMH_RequestHandler *rh,
 
       if (GNUNET_YES !=
           GNUNET_JSON_parse (contract_terms,
-                             spec,
+                             cspec,
                              NULL, NULL))
       {
         GNUNET_break (0);
-        GNUNET_JSON_parse_free (spec);
         json_decref (contract_terms);
         return TALER_MHD_reply_with_error (
           connection,
@@ -189,28 +224,6 @@ TMH_private_post_orders_ID_refund (const struct TMH_RequestHandler *rh,
            wire the funds, so we will try to give the refund anyway */
       }
     }
-    else
-    {
-      return TALER_MHD_reply_with_error (connection,
-                                         MHD_HTTP_NOT_FOUND,
-                                         TALER_EC_MERCHANT_GENERIC_ORDER_UNKNOWN,
-                                         hc->infix);
-    }
-  }
-
-  {
-    enum GNUNET_GenericReturnValue res;
-
-    res = TALER_MHD_parse_json_data (connection,
-                                     hc->request_body,
-                                     spec);
-    if (GNUNET_OK != res)
-    {
-      json_decref (contract_terms);
-      return (GNUNET_NO == res)
-             ? MHD_YES
-             : MHD_NO;
-    }
   }
 
   TMH_db->preflight (TMH_db->cls);
@@ -294,6 +307,14 @@ TMH_private_post_orders_ID_refund (const struct TMH_RequestHandler *rh,
 
   switch (rs)
   {
+  case TALER_MERCHANTDB_RS_BAD_CURRENCY:
+    GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                "Refund amount %s is not in the currency of the original payment\n",
+                TALER_amount2s (&refund));
+    return TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_CONFLICT,
+                                       TALER_EC_MERCHANT_GENERIC_CURRENCY_MISMATCH,
+                                       "Order was paid in a different currency");
   case TALER_MERCHANTDB_RS_TOO_HIGH:
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                 "Refusing refund amount %s that is larger than original payment\n",
@@ -309,53 +330,19 @@ TMH_private_post_orders_ID_refund (const struct TMH_RequestHandler *rh,
                                        TALER_EC_GENERIC_DB_COMMIT_FAILED,
                                        NULL);
   case TALER_MERCHANTDB_RS_NO_SUCH_ORDER:
-    {
-      /* We know the order exists from the
-         "lookup_contract_terms" at the beginning;
-         so if we get 'no such order' here, it
-         must be read as "no PAID order" */
-      return TALER_MHD_reply_with_error (
-        connection,
-        MHD_HTTP_CONFLICT,
-        TALER_EC_MERCHANT_PRIVATE_POST_ORDERS_ID_REFUND_ORDER_UNPAID,
-        hc->infix);
-    }
+    /* We know the order exists from the
+       "lookup_contract_terms" at the beginning;
+       so if we get 'no such order' here, it
+       must be read as "no PAID order" */
+    return TALER_MHD_reply_with_error (
+      connection,
+      MHD_HTTP_CONFLICT,
+      TALER_EC_MERCHANT_PRIVATE_POST_ORDERS_ID_REFUND_ORDER_UNPAID,
+      hc->infix);
   case TALER_MERCHANTDB_RS_SUCCESS:
-    {
-      enum GNUNET_DB_QueryStatus qs;
-      json_t *contract_terms;
-      uint64_t order_serial;
-      bool paid;
-
-      qs = TMH_db->lookup_contract_terms (TMH_db->cls,
-                                          hc->instance->settings.id,
-                                          hc->infix,
-                                          &contract_terms,
-                                          &order_serial,
-                                          &paid,
-                                          NULL);
-      if (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT != qs)
-      {
-        return TALER_MHD_reply_with_error (connection,
-                                           MHD_HTTP_NOT_FOUND,
-                                           TALER_EC_MERCHANT_GENERIC_ORDER_UNKNOWN,
-                                           hc->infix);
-      }
-      if (GNUNET_OK !=
-          TALER_JSON_contract_hash (contract_terms,
-                                    &h_contract))
-      {
-        GNUNET_break (0);
-        json_decref (contract_terms);
-        return TALER_MHD_reply_with_error (connection,
-                                           MHD_HTTP_INTERNAL_SERVER_ERROR,
-                                           TALER_EC_GENERIC_FAILED_COMPUTE_JSON_HASH,
-                                           "Could not hash contract terms");
-      }
-      json_decref (contract_terms);
-    }
+    /* continued below */
     break;
-  }
+  } /* end switch */
 
   {
     struct GNUNET_TIME_Timestamp timestamp;
