@@ -26,6 +26,7 @@
  */
 #include "platform.h"
 #include <gnunet/gnunet_common.h>
+#include <gnunet/gnunet_db_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <gnunet/gnunet_time_lib.h>
 #include <jansson.h>
@@ -34,6 +35,7 @@
 #include <taler/taler_error_codes.h>
 #include <taler/taler_signatures.h>
 #include <taler/taler_json_lib.h>
+#include <time.h>
 #include "taler-merchant-httpd.h"
 #include "taler-merchant-httpd_private-post-orders.h"
 #include "taler-merchant-httpd_exchanges.h"
@@ -376,14 +378,14 @@ struct OrderContext
     unsigned int choices_len;
 
     /**
-     * Array of token types referenced in the contract.
+     * Array of token families referenced in the contract.
      */
-    struct TALER_MerchantContractTokenAuthority *authorities;
+    struct TALER_MerchantContractTokenFamily *token_families;
 
     /**
-     * Length of the @e authorities array.
+     * Length of the @e token_families array.
      */
-    unsigned int authorities_len;
+    unsigned int token_families_len;
   } parse_choices;
 
   /**
@@ -679,7 +681,6 @@ clean_order (void *cls)
     json_decref (oc->merge_inventory.products);
     oc->merge_inventory.products = NULL;
   }
-  // TODO: Check if this is even correct
   for (unsigned int i = 0; i<oc->parse_choices.choices_len; i++)
   {
     GNUNET_array_grow (oc->parse_choices.choices[i].inputs,
@@ -689,6 +690,25 @@ clean_order (void *cls)
                        oc->parse_choices.choices[i].outputs_len,
                        0);
   }
+  GNUNET_array_grow (oc->parse_choices.choices,
+                     oc->parse_choices.choices_len,
+                     0);
+  for (unsigned int i = 0; i<oc->parse_choices.token_families_len; i++)
+  {
+    GNUNET_free (oc->parse_choices.token_families[i].name);
+    GNUNET_free (oc->parse_choices.token_families[i].description);
+    json_decref (oc->parse_choices.token_families[i].description_i18n);
+    for (unsigned int j = 0; j<oc->parse_choices.token_families[i].keys_len; j++)
+    {
+      GNUNET_CRYPTO_blind_sign_pub_decref(oc->parse_choices.token_families[i].keys[j].pub.public_key);
+    }
+    GNUNET_array_grow (oc->parse_choices.token_families[i].keys,
+                       oc->parse_choices.token_families[i].keys_len,
+                       0);
+  }
+  GNUNET_array_grow (oc->parse_choices.token_families,
+                     oc->parse_choices.token_families_len,
+                     0);
   GNUNET_array_grow (oc->parse_request.inventory_products,
                      oc->parse_request.inventory_products_length,
                      0);
@@ -1324,36 +1344,168 @@ get_exchange_keys (void *cls,
 
 
 /**
- * Fetch details about the token family with the given @a slug
- * and add them to the list of token authorities. Check if the
- * token family already has a valid key configured and if not,
- * create a new one.
+ * Get rounded time interval. @a start is calculated by rounding
+ * @a ts down to the nearest multiple of @a precision. @a end is
+ * the next higher multiple of @a precision.
+ *
+ * @param precision rounding precision.
+ *        year, month, day, hour, minute are supported.
+ * @param ts timestamp to round
+ * @param[out] start start of the interval
+ * @param[out] end end of the interval
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
+ */
+static enum GNUNET_GenericReturnValue
+get_rounded_time_interval (struct GNUNET_TIME_Relative precision,
+                           struct GNUNET_TIME_Timestamp ts,
+                           struct GNUNET_TIME_Timestamp *start,
+                           struct GNUNET_TIME_Timestamp *end)
+{
+  struct tm* timeinfo;
+  time_t seconds;
+
+  seconds = GNUNET_TIME_timestamp_to_s (ts);
+  timeinfo = localtime (&seconds);
+
+  if (GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_YEARS, ==, precision))
+  {
+    timeinfo->tm_mon = 0;
+    timeinfo->tm_mday = 1;
+    timeinfo->tm_hour = 0;
+    timeinfo->tm_min = 0;
+    timeinfo->tm_sec = 0;
+  }
+  else if (GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_MONTHS, ==, precision))
+  {
+    timeinfo->tm_mday = 1;
+    timeinfo->tm_hour = 0;
+    timeinfo->tm_min = 0;
+    timeinfo->tm_sec = 0;
+  }
+  else if (GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_DAYS, ==, precision))
+  {
+    timeinfo->tm_hour = 0;
+    timeinfo->tm_min = 0;
+    timeinfo->tm_sec = 0;
+  }
+  else if (GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_HOURS, ==, precision))
+  {
+    timeinfo->tm_min = 0;
+    timeinfo->tm_sec = 0;
+  }
+  else if (GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_MINUTES, ==, precision))
+  {
+    timeinfo->tm_sec = 0;
+  }
+  else
+  {
+    return GNUNET_SYSERR;
+  }
+
+  *start = GNUNET_TIME_timestamp_from_s (mktime (timeinfo));
+
+  if (GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_YEARS, ==, precision))
+  {
+    timeinfo->tm_year++;
+  }
+  else if (GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_MONTHS, ==, precision))
+  {
+    timeinfo->tm_mon = (timeinfo->tm_mon + 1) % 12;
+  }
+  else if (GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_DAYS, ==, precision))
+  {
+    timeinfo->tm_mday++;
+  }
+  else if (GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_HOURS, ==, precision))
+  {
+    timeinfo->tm_hour++;
+  }
+  else if (GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_MINUTES, ==, precision))
+  {
+    timeinfo->tm_min++;
+  }
+  else
+  {
+    return GNUNET_SYSERR;
+  }
+
+  *end = GNUNET_TIME_timestamp_from_s (mktime (timeinfo));
+  return GNUNET_OK;
+}
+
+/**
+ * Check if the token family with the given @a slug is already present in
+ * the list of token families for this order. If not, fetch its details and
+ * add it to the list. Then check if there is a public key with a matching
+ * @a valid_after field. If not, generate a new key pair and store it in the
+ * database.
  *
  * @param[in,out] oc order context
  * @param slug slug of the token family
- * @param start_date validity start date of the token
+ * @param[in,out] valid_after validity start date of the token,
+                  subject to rounding. Set to the rounded validity
+                  start date of the matching key.
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
  */
-static MHD_RESULT
-set_token_authority (struct OrderContext *oc,
-                     const char *slug,
-                     struct GNUNET_TIME_Timestamp start_date)
+static enum GNUNET_GenericReturnValue
+set_token_family (struct OrderContext *oc,
+                  const char *slug,
+                  struct GNUNET_TIME_Timestamp *valid_after)
 {
   struct TALER_MERCHANTDB_TokenFamilyKeyDetails key_details;
-  struct TALER_MerchantContractTokenAuthority authority;
+  struct TALER_MerchantContractTokenFamily *family = NULL;
   enum GNUNET_DB_QueryStatus qs;
-  struct GNUNET_TIME_Absolute min_start_date = GNUNET_TIME_absolute_subtract (
-    start_date.abs_time,
-    // TODO: make this configurable. This is the granularity of token
-    //       expiration dates.
-    GNUNET_TIME_UNIT_DAYS
-    );
+  /* TODO: Implement rounding duration of token family and use this here. */
+  struct GNUNET_TIME_Relative precision = GNUNET_TIME_UNIT_MONTHS;
+  struct GNUNET_TIME_Timestamp min_valid_after;
+  struct GNUNET_TIME_Timestamp max_valid_after;
+
+  if ( GNUNET_OK != get_rounded_time_interval (precision,
+                                               *valid_after,
+                                               &min_valid_after,
+                                               &max_valid_after))
+  {
+    GNUNET_break (0);
+    reply_with_error (oc,
+                      MHD_HTTP_INTERNAL_SERVER_ERROR,
+                      TALER_EC_GENERIC_INTERNAL_INVARIANT_FAILURE,
+                      "valid_after");
+    return GNUNET_SYSERR;
+  }
+
+  for (unsigned int i = 0; i<oc->parse_choices.token_families_len; i++)
+  {
+    if (0 == strcmp (oc->parse_choices.token_families[i].slug,
+                     slug))
+    {
+      family = &oc->parse_choices.token_families[i];
+      break;
+    }
+  }
+
+  if (NULL != family)
+  {
+    for (unsigned int i = 0; i<family->keys_len; i++)
+    {
+      if (GNUNET_TIME_timestamp_cmp (family->keys[i].valid_after,
+                                     >=,
+                                     min_valid_after)
+          && GNUNET_TIME_timestamp_cmp (family->keys[i].valid_after,
+                                        <,
+                                        max_valid_after))
+      {
+        /* The token family and a matching key is already added. */
+        *valid_after = family->keys[i].valid_after;
+        return GNUNET_OK;
+      }
+    }
+  }
 
   qs = TMH_db->lookup_token_family_key (TMH_db->cls,
                                         oc->hc->instance->settings.id,
                                         slug,
-                                        GNUNET_TIME_absolute_to_timestamp (
-                                          min_start_date),
-                                        start_date,
+                                        min_valid_after,
+                                        max_valid_after,
                                         &key_details);
 
   if (qs <= 0)
@@ -1386,85 +1538,164 @@ set_token_authority (struct OrderContext *oc,
                       http_status,
                       ec,
                       "token_family_slug");
-    return MHD_NO;
+    return GNUNET_SYSERR;
   }
 
-  if (NULL == key_details.pub)
+  struct GNUNET_TIME_Timestamp now = GNUNET_TIME_timestamp_get ();
+
+  /* Verify that the token family is valid right now. */
+  if (GNUNET_TIME_timestamp_cmp (key_details.token_family.valid_after, >, now) ||
+      GNUNET_TIME_timestamp_cmp (key_details.token_family.valid_before, <=, now))
   {
-    /* If public key is NULL, private key must also be NULL */
-    GNUNET_assert (NULL == key_details.priv);
-
-    struct GNUNET_CRYPTO_BlindSignPrivateKey *priv;
-    struct GNUNET_CRYPTO_BlindSignPublicKey *pub;
-    struct GNUNET_TIME_Absolute now = GNUNET_TIME_absolute_get ();
-    struct GNUNET_TIME_Timestamp valid_before =
-      GNUNET_TIME_absolute_to_timestamp (
-        GNUNET_TIME_absolute_add (now,
-                                  key_details.token_family.duration));
-
-    GNUNET_CRYPTO_blind_sign_keys_create (&priv,
-                                          &pub,
-                                          // TODO: Make cipher and key length configurable
-                                          GNUNET_CRYPTO_BSA_RSA,
-                                          4096);
-
-    struct TALER_TokenFamilyPublicKey token_pub = {
-      .public_key = *pub,
-    };
-    struct TALER_TokenFamilyPrivateKey token_priv = {
-      .private_key = *priv,
-    };
-
-    qs = TMH_db->insert_token_family_key (TMH_db->cls,
-                                          slug,
-                                          &token_pub,
-                                          &token_priv,
-                                          GNUNET_TIME_absolute_to_timestamp (now
-                                                                             ),
-                                          valid_before);
-
-    authority.token_expiration = valid_before;
-    authority.pub = &token_pub;
-    // GNUNET_CRYPTO_blind_sign_priv_decref (&token_priv.private_key);
-  }
-  else
-  {
-    authority.token_expiration = key_details.valid_before;
-    authority.pub = key_details.pub;
+    GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                "Token family expired or not yet valid\n");
+    reply_with_error (oc,
+                      /* TODO: HTTP Status Code GONE would be more elegant,
+                               but that is already used to indicate that a product is out of stock. */
+                      MHD_HTTP_CONFLICT,
+                      TALER_EC_MERCHANT_PRIVATE_POST_ORDERS_TOKEN_FAMILY_NOT_VALID,
+                      key_details.token_family.slug);
+    return GNUNET_SYSERR;
   }
 
-  authority.label = slug;
-  authority.description = key_details.token_family.description;
-  authority.description_i18n = key_details.token_family.description_i18n;
-
+  /* slug is not needed */
   GNUNET_free (key_details.token_family.slug);
-  GNUNET_free (key_details.token_family.name);
-  if (NULL != key_details.priv)
+
   {
-    GNUNET_CRYPTO_blind_sign_priv_decref (&key_details.priv->private_key);
+    struct TALER_MerchantContractTokenFamilyKey key;
+
+    if (NULL == family)
+    {
+      struct TALER_MerchantContractTokenFamily new_family = {
+        .slug = slug,
+        .name = key_details.token_family.name,
+        .description = key_details.token_family.description,
+        .description_i18n = key_details.token_family.description_i18n,
+        .keys = GNUNET_new (struct TALER_MerchantContractTokenFamilyKey),
+        .keys_len = 0,
+      };
+
+      switch (key_details.token_family.kind) {
+      case TALER_MERCHANTDB_TFK_Subscription:
+        new_family.kind = TALER_MCTK_SUBSCRIPTION;
+        new_family.critical = true;
+        // TODO: Set trusted domains
+        break;
+      case TALER_MERCHANTDB_TFK_Discount:
+        new_family.kind = TALER_MCTK_DISCOUNT;
+        new_family.critical = false;
+        // TODO: Set expected domains
+        break;
+      }
+
+      GNUNET_array_append (oc->parse_choices.token_families,
+                          oc->parse_choices.token_families_len,
+                          new_family);
+
+      family = &oc->parse_choices.token_families[oc->parse_choices.token_families_len - 1];
+    }
+
+    if (NULL == key_details.pub.public_key)
+    {
+      /* There is no matching key for this token family yet. */
+      /* We have to generate a fresh key pair. */
+      /* If public key is NULL, private key must also be NULL */
+      GNUNET_assert (NULL == key_details.priv.private_key);
+
+      enum GNUNET_DB_QueryStatus iqs;
+      struct GNUNET_CRYPTO_BlindSignPrivateKey *priv;
+      struct GNUNET_CRYPTO_BlindSignPublicKey *pub;
+      struct GNUNET_TIME_Timestamp valid_before =
+        GNUNET_TIME_absolute_to_timestamp (
+          GNUNET_TIME_absolute_add (min_valid_after.abs_time,
+                                    key_details.token_family.duration));
+
+      if (GNUNET_TIME_timestamp_cmp (min_valid_after,
+                                     <,
+                                     key_details.token_family.valid_after))
+      {
+        /* If key would start before validity of token family,
+           set valid_after of key to the value of the token family. */
+        min_valid_after = key_details.token_family.valid_after;
+      }
+
+      if (GNUNET_TIME_timestamp_cmp (valid_before,
+                                     >,
+                                     key_details.token_family.valid_before))
+      {
+        /* If key would end after validity of token family,
+           set valid_before of key to the value of the token family. */
+        valid_before = key_details.token_family.valid_before;
+      }
+
+      GNUNET_CRYPTO_blind_sign_keys_create (&priv,
+                                            &pub,
+                                            /* TODO: Make cipher and key length configurable */
+                                            GNUNET_CRYPTO_BSA_RSA,
+                                            4096);
+
+      struct TALER_TokenIssuePublicKeyP token_pub = {
+        .public_key = pub,
+      };
+      struct TALER_TokenIssuePrivateKeyP token_priv = {
+        .private_key = priv,
+      };
+
+      iqs = TMH_db->insert_token_family_key (TMH_db->cls,
+                                             slug,
+                                             &token_pub,
+                                             &token_priv,
+                                             min_valid_after,
+                                             valid_before);
+
+      GNUNET_CRYPTO_blind_sign_priv_decref (priv);
+
+      if (iqs <= 0)
+      {
+        enum TALER_ErrorCode ec = TALER_EC_GENERIC_INTERNAL_INVARIANT_FAILURE;
+        unsigned int http_status = 0;
+
+        switch (iqs)
+        {
+        case GNUNET_DB_STATUS_HARD_ERROR:
+          http_status = MHD_HTTP_INTERNAL_SERVER_ERROR;
+          ec = TALER_EC_GENERIC_DB_STORE_FAILED;
+          break;
+        case GNUNET_DB_STATUS_SOFT_ERROR:
+        case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
+          http_status = MHD_HTTP_INTERNAL_SERVER_ERROR;
+          ec = TALER_EC_GENERIC_DB_SOFT_FAILURE;
+          break;
+        case GNUNET_DB_STATUS_SUCCESS_ONE_RESULT:
+          /* case listed to make compilers happy */
+          GNUNET_assert (0);
+        }
+
+        GNUNET_break (0);
+        reply_with_error (oc,
+                          http_status,
+                          ec,
+                          "token_family_slug");
+        return GNUNET_SYSERR;
+      }
+
+      key.pub = token_pub;
+      key.valid_after = min_valid_after;
+      key.valid_before = valid_before;
+    } else {
+      key.pub = key_details.pub;
+      key.valid_after = key_details.valid_after;
+      key.valid_before = key_details.valid_before;
+    }
+
+    GNUNET_array_append (family->keys,
+                         family->keys_len,
+                         key);
+
+    *valid_after = key.valid_after;
   }
 
-  switch (key_details.token_family.kind)
-  {
-  case TALER_MERCHANTDB_TFK_Subscription:
-    authority.kind = TALER_MCTK_SUBSCRIPTION;
-    authority.details.subscription.start_date = key_details.valid_after;
-    authority.details.subscription.end_date = key_details.valid_before;
-    authority.critical = true;
-    // TODO: Set trusted domains
-    break;
-  case TALER_MERCHANTDB_TFK_Discount:
-    authority.kind = TALER_MCTK_DISCOUNT;
-    authority.critical = false;
-    // TODO: Set expected domains
-    break;
-  }
-
-  GNUNET_array_append (oc->parse_choices.authorities,
-                       oc->parse_choices.authorities_len,
-                       authority);
-
-  return MHD_YES;
+  return GNUNET_OK;
 }
 
 
@@ -1481,7 +1712,7 @@ serialize_order (struct OrderContext *oc)
   const struct TALER_MERCHANTDB_InstanceSettings *settings =
     &oc->hc->instance->settings;
   json_t *merchant;
-  json_t *token_types = json_object ();
+  json_t *token_families = json_object ();
   json_t *choices = json_array ();
 
   merchant = GNUNET_JSON_PACK (
@@ -1528,38 +1759,54 @@ serialize_order (struct OrderContext *oc)
     }
   }
 
-  for (unsigned int i = 0; i<oc->parse_choices.authorities_len; i++)
+  for (unsigned int i = 0; i<oc->parse_choices.token_families_len; i++)
   {
-    struct TALER_MerchantContractTokenAuthority *authority = &oc->parse_choices.
-                                                             authorities[i];
+    json_t *keys = json_array();
+    struct TALER_MerchantContractTokenFamily *family = &oc->parse_choices.token_families[i];
 
-    // TODO: Finish spec to clearly define how token families are stored in
-    //       ContractTerms.
-    //       Here are some thoughts:
-    //       - Multiple keys of the same token family can be referenced in
-    //         one contract. E.g. exchanging old subscription for new.
-    //       - TokenAuthority should be renamed to TokenFamily for consistency.
-    //       - TokenFamilySlug can be used instead of TokenAuthorityLabel, but
-    //         every token-based in- or output needs to have a valid_after date,
-    //         so it's clear with key is referenced.
-    json_t *jauthority = GNUNET_JSON_PACK (
-      GNUNET_JSON_pack_string ("description",
-                               authority->description),
-      GNUNET_JSON_pack_allow_null (
-        GNUNET_JSON_pack_object_incref ("description_i18n",
-                                        authority->description_i18n)),
-      GNUNET_JSON_pack_data_auto ("h_pub",
-                                  &authority->pub->public_key.pub_key_hash),
-      GNUNET_JSON_pack_data_auto ("pub",
-                                  &authority->pub->public_key.pub_key_hash),
-      GNUNET_JSON_pack_timestamp ("token_expiration",
-                                  authority->token_expiration)
+    for (unsigned int j = 0; j<family->keys_len; j++)
+    {
+      struct TALER_MerchantContractTokenFamilyKey key = family->keys[j];
+
+      json_t *jkey = GNUNET_JSON_PACK (
+        /* TODO: Remove h_pub. */
+        GNUNET_JSON_pack_data_auto ("h_pub",
+                                    &key.pub.public_key->pub_key_hash),
+        GNUNET_JSON_pack_allow_null(
+          GNUNET_JSON_pack_rsa_public_key ("rsa_pub",
+                                           key.pub.public_key->details.rsa_public_key)),
+        // GNUNET_JSON_pack_allow_null(
+        //   GNUNET_JSON_pack_data_auto ("cs_pub",
+        //                               &key.pub.public_key->details.cs_public_key)),
+        GNUNET_JSON_pack_int64 ("cipher",
+                                key.pub.public_key->cipher),
+        GNUNET_JSON_pack_timestamp ("valid_after",
+                                    key.valid_after),
+        GNUNET_JSON_pack_timestamp ("valid_before",
+                                    key.valid_before)
       );
 
-    GNUNET_assert (0 ==
-                   json_object_set_new (token_types,
-                                        authority->label,
-                                        jauthority));
+      GNUNET_assert (0 == json_array_append_new (keys, jkey));
+    }
+
+    /* TODO: Add 'details' field. */
+    json_t *jfamily = GNUNET_JSON_PACK (
+      GNUNET_JSON_pack_string ("name",
+                               family->name),
+      GNUNET_JSON_pack_string ("description",
+                               family->description),
+      GNUNET_JSON_pack_allow_null (
+        GNUNET_JSON_pack_object_incref ("description_i18n",
+                                        family->description_i18n)),
+      GNUNET_JSON_pack_array_steal ("keys",
+                                    keys),
+      GNUNET_JSON_pack_bool ("critical",
+                             family->critical)
+    );
+
+    GNUNET_assert (0 == json_object_set_new (token_families,
+                                             family->slug,
+                                             jfamily));
   }
 
   for (unsigned int i = 0; i<oc->parse_choices.choices_len; i++)
@@ -1573,25 +1820,19 @@ serialize_order (struct OrderContext *oc)
     {
       struct TALER_MerchantContractInput *input = &choice->inputs[j];
 
-      json_t *jinput = GNUNET_JSON_PACK (
-        GNUNET_JSON_pack_int64 ("type",
-                                input->type)
-        );
+      /* For now, only tokens are supported */
+      GNUNET_assert (TALER_MCIT_TOKEN == input->type);
 
-      if (TALER_MCIT_TOKEN == input->type)
-      {
-        GNUNET_assert (0 ==
-                       json_object_set_new (jinput,
-                                            "number",
-                                            json_integer (
-                                              input->details.token.count)));
-        GNUNET_assert (0 ==
-                       json_object_set_new (jinput,
-                                            "token_family_slug",
-                                            json_string (
-                                              input->details.token.
-                                              token_family_slug)));
-      }
+      json_t *jinput = GNUNET_JSON_PACK (
+        GNUNET_JSON_pack_string ("kind",
+                                 TMH_string_from_contract_input_type (input->type)),
+        GNUNET_JSON_pack_string ("token_family_slug",
+                                 input->details.token.token_family_slug),
+        GNUNET_JSON_pack_int64 ("number",
+                                input->details.token.count),
+        GNUNET_JSON_pack_timestamp ("valid_after",
+                                    input->details.token.valid_after)
+      );
 
       GNUNET_assert (0 == json_array_append_new (inputs, jinput));
     }
@@ -1600,26 +1841,19 @@ serialize_order (struct OrderContext *oc)
     {
       struct TALER_MerchantContractOutput *output = &choice->outputs[j];
 
+      /* For now, only tokens are supported */
+      GNUNET_assert (TALER_MCOT_TOKEN == output->type);
+
       json_t *joutput = GNUNET_JSON_PACK (
-        GNUNET_JSON_pack_int64 ("type",
-                                output->type)
-        );
-
-      if (TALER_MCOT_TOKEN == output->type)
-      {
-        GNUNET_assert (0 ==
-                       json_object_set_new (joutput,
-                                            "number",
-                                            json_integer (
-                                              output->details.token.count)));
-
-        GNUNET_assert (0 ==
-                       json_object_set_new (joutput,
-                                            "token_family_slug",
-                                            json_string (
-                                              output->details.token.
-                                              token_family_slug)));
-      }
+        GNUNET_JSON_pack_string ("kind",
+                                 TMH_string_from_contract_output_type (output->type)),
+        GNUNET_JSON_pack_string ("token_family_slug",
+                                 output->details.token.token_family_slug),
+        GNUNET_JSON_pack_int64 ("number",
+                                output->details.token.count),
+        GNUNET_JSON_pack_timestamp ("valid_after",
+                                    output->details.token.valid_after)
+      );
 
       GNUNET_assert (0 == json_array_append (outputs, joutput));
     }
@@ -1691,13 +1925,13 @@ serialize_order (struct OrderContext *oc)
     TALER_JSON_pack_amount ("amount",
                             &oc->parse_order.brutto),
     GNUNET_JSON_pack_allow_null (
-      GNUNET_JSON_pack_array_incref ("choices",
-                                     choices)
-      ),
+      GNUNET_JSON_pack_array_steal ("choices",
+                                      choices)
+    ),
     GNUNET_JSON_pack_allow_null (
-      GNUNET_JSON_pack_object_incref ("token_types",
-                                      token_types)
-      ),
+      GNUNET_JSON_pack_object_steal ("token_families",
+                                      token_families)
+    ),
     GNUNET_JSON_pack_allow_null (
       GNUNET_JSON_pack_object_incref ("extra",
                                       (json_t *) oc->parse_order.extra))
@@ -1780,8 +2014,8 @@ set_max_fee (struct OrderContext *oc)
 static bool
 set_exchanges (struct OrderContext *oc)
 {
-  /* Note: re-building 'oc->exchanges' every time here might be a tad
-     expensive; could likely consider caching the result if it starts to
+  /* Note: re-building 'oc->set_exchanges.exchanges' every time here might be a
+     tad expensive; could likely consider caching the result if it starts to
      matter. */
   if (NULL == oc->set_exchanges.exchanges)
   {
@@ -1852,6 +2086,8 @@ parse_order (struct OrderContext *oc)
    * mostly because in GNUnet relative times can't
    * be negative.  */
   bool no_fee;
+  /* TODO: Move "amount" field to choices. This entails moving the
+           stefan-base fee calculation to the parse_choices phase. */
   struct GNUNET_JSON_Specification spec[] = {
     GNUNET_JSON_spec_mark_optional (
       GNUNET_JSON_spec_string ("version",
@@ -2314,10 +2550,14 @@ parse_choices (struct OrderContext *oc)
     const json_t *jinputs;
     const json_t *joutputs;
     struct GNUNET_JSON_Specification spec[] = {
-      GNUNET_JSON_spec_array_const ("inputs",
-                                    &jinputs),
-      GNUNET_JSON_spec_array_const ("outputs",
-                                    &joutputs),
+      GNUNET_JSON_spec_mark_optional (
+        GNUNET_JSON_spec_array_const ("inputs",
+                                      &jinputs),
+        NULL),
+      GNUNET_JSON_spec_mark_optional (
+        GNUNET_JSON_spec_array_const ("outputs",
+                                      &joutputs),
+        NULL),
       GNUNET_JSON_spec_end ()
     };
     enum GNUNET_GenericReturnValue ret;
@@ -2339,14 +2579,15 @@ parse_choices (struct OrderContext *oc)
       return;
     }
 
-    if (! json_is_array (jinputs) ||
-        ! json_is_array (joutputs))
+    if (0 == json_array_size(jinputs) && 0 == json_array_size(joutputs))
     {
-      GNUNET_break_op (0);
+      GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                  "Choice #%u must have at least one input or output\n",
+                  i);
       reply_with_error (oc,
                         MHD_HTTP_BAD_REQUEST,
                         TALER_EC_GENERIC_PARAMETER_MALFORMED,
-                        "inputs or outputs");
+                        "choice");
       return;
     }
 
@@ -2356,10 +2597,6 @@ parse_choices (struct OrderContext *oc)
       size_t idx;
       json_array_foreach ((json_t *) jinputs, idx, jinput)
       {
-        // TODO: Assuming this struct would have more fields, would i use GNUNET_new then?
-        //       Or should i use GNUNET_grow first and then get the element using the index?
-        //       Assuming you add a field in the future, it's easier to that way, so you don't
-        //       free it.
         struct TALER_MerchantContractInput input = {.details.token.count = 1};
         const char *kind;
         const char *ierror_name;
@@ -2370,6 +2607,8 @@ parse_choices (struct OrderContext *oc)
                                    &kind),
           GNUNET_JSON_spec_string ("token_family_slug",
                                    &input.details.token.token_family_slug),
+          /* TODO: Remove valid_after field for inputs,
+                   use current system time instead. */
           GNUNET_JSON_spec_timestamp ("valid_after",
                                       &input.details.token.valid_after),
           GNUNET_JSON_spec_mark_optional (
@@ -2396,7 +2635,7 @@ parse_choices (struct OrderContext *oc)
           return;
         }
 
-        input.type = TMH_string_to_contract_input_type (kind);
+        input.type = TMH_contract_input_type_from_string (kind);
 
         if (TALER_MCIT_INVALID == input.type)
         {
@@ -2416,29 +2655,12 @@ parse_choices (struct OrderContext *oc)
           continue;
         }
 
-        bool found = false;
-
-        for (unsigned int i = 0; i<oc->parse_choices.authorities_len; i++)
+        if (GNUNET_OK != set_token_family (oc,
+                            input.details.token.token_family_slug,
+                            &input.details.token.valid_after))
         {
-          if (0 == strcmp (oc->parse_choices.authorities[i].label,
-                           input.details.token.token_family_slug))
-          {
-            found = true;
-            break;
-          }
-        }
-
-        if (! found)
-        {
-          MHD_RESULT res;
-          res = set_token_authority (oc,
-                                     input.details.token.token_family_slug,
-                                     input.details.token.valid_after);
-
-          if (MHD_NO == res)
-          {
-            return;
-          }
+          /* error is already scheduled, return. */
+          return;
         }
 
         GNUNET_array_append (oc->parse_choices.choices[i].inputs,
@@ -2463,6 +2685,7 @@ parse_choices (struct OrderContext *oc)
                                    &kind),
           GNUNET_JSON_spec_string ("token_family_slug",
                                    &output.details.token.token_family_slug),
+          /* TODO: Make valid_after optional, default to current system time. */
           GNUNET_JSON_spec_timestamp ("valid_after",
                                       &output.details.token.valid_after),
           GNUNET_JSON_spec_mark_optional (
@@ -2491,7 +2714,7 @@ parse_choices (struct OrderContext *oc)
           return;
         }
 
-        output.type = TMH_string_to_contract_output_type (kind);
+        output.type = TMH_contract_output_type_from_string (kind);
 
         if (TALER_MCOT_INVALID == output.type)
         {
@@ -2509,33 +2732,16 @@ parse_choices (struct OrderContext *oc)
 
         if (0 == output.details.token.count)
         {
-          /* Ignore outputs with 'number' field set to 0 */
+          /* Ignore outputs with 'number' field set to 0. */
           continue;
         }
 
-        bool found = false;
-
-        for (unsigned int i = 0; i<oc->parse_choices.authorities_len; i++)
+        if (GNUNET_OK != set_token_family (oc,
+                            output.details.token.token_family_slug,
+                            &output.details.token.valid_after))
         {
-          if (0 == strcmp (oc->parse_choices.authorities[i].label,
-                           output.details.token.token_family_slug))
-          {
-            found = true;
-            break;
-          }
-        }
-
-        if (! found)
-        {
-          MHD_RESULT res;
-          res = set_token_authority (oc,
-                                     output.details.token.token_family_slug,
-                                     output.details.token.valid_after);
-
-          if (MHD_NO == res)
-          {
-            return;
-          }
+          /* Error is already scheduled, return. */
+          return;
         }
 
         GNUNET_array_append (oc->parse_choices.choices[i].outputs,
@@ -2651,7 +2857,6 @@ merge_inventory (struct OrderContext *oc)
           /* case listed to make compilers happy */
           GNUNET_assert (0);
         }
-        json_decref (oc->merge_inventory.products);
         reply_with_error (oc,
                           http_status,
                           ec,
