@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  (C) 2023 Taler Systems SA
+  (C) 2023, 2024 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify
   it under the terms of the GNU Affero General Public License as
@@ -25,6 +25,7 @@
 #include "platform.h"
 #include "taler-merchant-httpd_private-post-token-families.h"
 #include "taler-merchant-httpd_helper.h"
+#include <gnunet/gnunet_time_lib.h>
 #include <taler/taler_json_lib.h>
 
 
@@ -74,6 +75,7 @@ TMH_private_post_token_families (const struct TMH_RequestHandler *rh,
   struct TMH_MerchantInstance *mi = hc->instance;
   struct TALER_MERCHANTDB_TokenFamilyDetails details = { 0 };
   const char *kind = NULL;
+  bool no_valid_after = false;
   enum GNUNET_DB_QueryStatus qs;
   struct GNUNET_JSON_Specification spec[] = {
     GNUNET_JSON_spec_string ("slug",
@@ -86,15 +88,22 @@ TMH_private_post_token_families (const struct TMH_RequestHandler *rh,
       GNUNET_JSON_spec_json ("description_i18n",
                              &details.description_i18n),
       NULL),
-    GNUNET_JSON_spec_string ("kind", &kind),
-    GNUNET_JSON_spec_timestamp ("valid_after",
-                                &details.valid_after),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_timestamp ("valid_after",
+                                  &details.valid_after),
+      &no_valid_after),
     GNUNET_JSON_spec_timestamp ("valid_before",
                                 &details.valid_before),
     GNUNET_JSON_spec_relative_time ("duration",
                                     &details.duration),
+    GNUNET_JSON_spec_relative_time ("rounding",
+                                    &details.rounding),
+    GNUNET_JSON_spec_string ("kind",
+                             &kind),
     GNUNET_JSON_spec_end ()
   };
+  struct GNUNET_TIME_Timestamp now
+    = GNUNET_TIME_timestamp_get ();
 
   GNUNET_assert (NULL != mi);
   {
@@ -111,11 +120,42 @@ TMH_private_post_token_families (const struct TMH_RequestHandler *rh,
              : MHD_NO;
     }
   }
+  if (no_valid_after)
+    details.valid_after = now;
 
+  /* Ensure that valid_after is before valid_before */
+  if (GNUNET_TIME_timestamp_cmp (details.valid_after,
+                                 >=,
+                                 details.valid_before))
+  {
+    GNUNET_break (0);
+    GNUNET_JSON_parse_free (spec);
+    return TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_BAD_REQUEST,
+                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
+                                       "valid_before");
+  }
 
-  if (strcmp (kind, "discount") == 0)
+  /* Ensure that valid_after is not in the past */
+  if (GNUNET_TIME_timestamp_cmp (details.valid_after,
+                                 <,
+                                 now))
+  {
+    GNUNET_break (0);
+    GNUNET_JSON_parse_free (spec);
+    return TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_BAD_REQUEST,
+                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
+                                       "valid_after");
+  }
+
+  if (0 ==
+      strcmp (kind,
+              "discount"))
     details.kind = TALER_MERCHANTDB_TFK_Discount;
-  else if (strcmp (kind, "subscription") == 0)
+  else if (0 ==
+           strcmp (kind,
+                   "subscription"))
     details.kind = TALER_MERCHANTDB_TFK_Subscription;
   else
   {
@@ -140,6 +180,34 @@ TMH_private_post_token_families (const struct TMH_RequestHandler *rh,
                                        "description_i18n");
   }
 
+  if (GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_YEARS,
+                                !=,
+                                details.rounding) &&
+      GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_MONTHS,
+                                !=,
+                                details.rounding) &&
+      GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_DAYS,
+                                !=,
+                                details.rounding) &&
+      GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_HOURS,
+                                !=,
+                                details.rounding) &&
+      GNUNET_TIME_relative_cmp (GNUNET_TIME_UNIT_MINUTES,
+                                !=,
+                                details.rounding)
+      )
+  {
+    GNUNET_break (0);
+    GNUNET_JSON_parse_free (spec);
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                "Received invalid rounding value: %s\n",
+                GNUNET_STRINGS_relative_time_to_string (details.rounding,
+                                                        true));
+    return TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_BAD_REQUEST,
+                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
+                                       "rounding");
+  }
 
   /* finally, interact with DB until no serialization error */
   for (unsigned int i = 0; i<MAX_RETRIES; i++)
