@@ -15,7 +15,7 @@
 */
 /**
  * @file taler-merchant-httpd_statics.c
- * @brief logic to load and complete HTML templates
+ * @brief logic to load and return static resource files by client language preference
  * @author Christian Grothoff
  */
 #include "platform.h"
@@ -144,7 +144,7 @@ TMH_return_static (const struct TMH_RequestHandler *rh,
  *  #GNUNET_NO to stop iteration with no error,
  *  #GNUNET_SYSERR to abort iteration with error!
  */
-static int
+static enum GNUNET_GenericReturnValue
 load_static_file (void *cls,
                   const char *filename)
 {
@@ -275,7 +275,7 @@ load_static_file (void *cls,
 /**
  * Preload static files.
  */
-int
+enum GNUNET_GenericReturnValue
 TMH_statics_init ()
 {
   char *dn;
@@ -291,19 +291,23 @@ TMH_statics_init ()
       return GNUNET_SYSERR;
     }
     GNUNET_asprintf (&dn,
-                     "%s/merchant/static/",
+                     "%smerchant/static/",
                      path);
     GNUNET_free (path);
   }
   ret = GNUNET_DISK_directory_scan (dn,
                                     &load_static_file,
                                     NULL);
-  GNUNET_free (dn);
   if (-1 == ret)
   {
-    GNUNET_break (0);
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Could not load static resources from `%s': %s\n",
+                dn,
+                strerror (errno));
+    GNUNET_free (dn);
     return GNUNET_SYSERR;
   }
+  GNUNET_free (dn);
   return GNUNET_OK;
 }
 
