@@ -29,38 +29,25 @@ enum GNUNET_DB_QueryStatus
 TMH_PG_insert_token_family (void *cls,
                             const char *instance_id,
                             const char *token_family_slug,
-                            const struct TALER_MERCHANTDB_TokenFamilyDetails *details)
+                            const struct TALER_MERCHANTDB_TokenFamilyDetails *
+                            details)
 {
   struct PostgresClosure *pg = cls;
-
   const char *kind;
+
   switch (details->kind)
   {
-    case TALER_MERCHANTDB_TFK_Discount:
-      kind = "discount";
-      break;
-    case TALER_MERCHANTDB_TFK_Subscription:
-      kind = "subscription";
-      break;
-    default:
-      GNUNET_break (0);
-      return GNUNET_DB_STATUS_HARD_ERROR;
+  case TALER_MERCHANTDB_TFK_Discount:
+    kind = "discount";
+    break;
+  case TALER_MERCHANTDB_TFK_Subscription:
+    kind = "subscription";
+    break;
+  default:
+    GNUNET_break (0);
+    return GNUNET_DB_STATUS_HARD_ERROR;
   }
 
-  struct GNUNET_PQ_QueryParam params[] = {
-    GNUNET_PQ_query_param_string (instance_id),
-    GNUNET_PQ_query_param_string (token_family_slug),
-    GNUNET_PQ_query_param_string (details->name),
-    GNUNET_PQ_query_param_string (details->description),
-    TALER_PQ_query_param_json (details->description_i18n),
-    GNUNET_PQ_query_param_timestamp (&details->valid_after),
-    GNUNET_PQ_query_param_timestamp (&details->valid_before),
-    GNUNET_PQ_query_param_relative_time (&details->duration),
-    GNUNET_PQ_query_param_relative_time (&details->rounding),
-    GNUNET_PQ_query_param_string (kind),
-    GNUNET_PQ_query_param_end
-  };
-
   check_connection (pg);
   PREPARE (pg,
            "insert_token_family",
@@ -78,7 +65,23 @@ TMH_PG_insert_token_family (void *cls,
            " SELECT merchant_serial, $2, $3, $4, $5, $6, $7, $8, $9, $10"
            " FROM merchant_instances"
            " WHERE merchant_id=$1");
-  return GNUNET_PQ_eval_prepared_non_select (pg->conn,
-                                             "insert_token_family",
-                                             params);
+  {
+    struct GNUNET_PQ_QueryParam params[] = {
+      GNUNET_PQ_query_param_string (instance_id),
+      GNUNET_PQ_query_param_string (token_family_slug),
+      GNUNET_PQ_query_param_string (details->name),
+      GNUNET_PQ_query_param_string (details->description),
+      TALER_PQ_query_param_json (details->description_i18n),
+      GNUNET_PQ_query_param_timestamp (&details->valid_after),
+      GNUNET_PQ_query_param_timestamp (&details->valid_before),
+      GNUNET_PQ_query_param_relative_time (&details->duration),
+      GNUNET_PQ_query_param_relative_time (&details->rounding),
+      GNUNET_PQ_query_param_string (kind),
+      GNUNET_PQ_query_param_end
+    };
+
+    return GNUNET_PQ_eval_prepared_non_select (pg->conn,
+                                               "insert_token_family",
+                                               params);
+  }
 }
