@@ -55,20 +55,8 @@ TMH_PG_insert_token_family_key (void *cls,
   case GNUNET_CRYPTO_BSA_INVALID:
     return GNUNET_DB_STATUS_HARD_ERROR;
   }
-
-  struct GNUNET_PQ_QueryParam params[] = {
-    GNUNET_PQ_query_param_string (token_family_slug),
-    GNUNET_PQ_query_param_blind_sign_pub (pub->public_key),
-    GNUNET_PQ_query_param_auto_from_type (&pub->public_key->pub_key_hash),
-    GNUNET_PQ_query_param_blind_sign_priv (priv->private_key),
-    GNUNET_PQ_query_param_timestamp (&valid_after),
-    GNUNET_PQ_query_param_timestamp (&valid_before),
-    GNUNET_PQ_query_param_string (cipher),
-    GNUNET_PQ_query_param_end
-  };
-
-  GNUNET_assert (pub->public_key->cipher == priv->private_key->cipher);
-
+  GNUNET_assert (pub->public_key->cipher ==
+                 priv->private_key->cipher);
   GNUNET_assert (0 ==
                  GNUNET_memcmp (&pub_hash,
                                 &pub->public_key->pub_key_hash));
@@ -90,7 +78,20 @@ TMH_PG_insert_token_family_key (void *cls,
            " SELECT token_family_serial, $2, $3, $4, $5, $6, $7"
            " FROM merchant_token_families"
            " WHERE slug = $1");
-  return GNUNET_PQ_eval_prepared_non_select (pg->conn,
-                                             "token_family_key_insert",
-                                             params);
-}
\ No newline at end of file
+  {
+    struct GNUNET_PQ_QueryParam params[] = {
+      GNUNET_PQ_query_param_string (token_family_slug),
+      GNUNET_PQ_query_param_blind_sign_pub (pub->public_key),
+      GNUNET_PQ_query_param_auto_from_type (&pub->public_key->pub_key_hash),
+      GNUNET_PQ_query_param_blind_sign_priv (priv->private_key),
+      GNUNET_PQ_query_param_timestamp (&valid_after),
+      GNUNET_PQ_query_param_timestamp (&valid_before),
+      GNUNET_PQ_query_param_string (cipher),
+      GNUNET_PQ_query_param_end
+    };
+
+    return GNUNET_PQ_eval_prepared_non_select (pg->conn,
+                                               "token_family_key_insert",
+                                               params);
+  }
+}
