@@ -73,8 +73,7 @@ TMH_PG_select_account_by_uri (void *cls,
            "  (SELECT merchant_serial "
            "    FROM merchant_instances"
            "    WHERE merchant_id=$1)"
-           "      AND REGEXP_REPLACE(payto_uri,'\\?.*','')"
-           "         =REGEXP_REPLACE($2,'\\?.*','')");
+           "      AND payto_uri = $2");
   return GNUNET_PQ_eval_prepared_singleton_select (pg->conn,
                                                    "select_account_by_uri",
                                                    params,
