@@ -147,6 +147,9 @@
 #include "pg_update_token_family.h"
 #include "pg_insert_token_family_key.h"
 #include "pg_lookup_token_family_key.h"
+#include "pg_insert_spent_token.h"
+#include "pg_insert_issued_token.h"
+#include "pg_lookup_spent_tokens_by_order.h"
 
 
 /**
@@ -604,6 +607,14 @@ libtaler_plugin_merchantdb_postgres_init (void *cls)
     = &TMH_PG_lookup_token_family_key;
   plugin->update_deposit_confirmation_status
     = &TMH_PG_update_deposit_confirmation_status;
+  plugin->insert_spent_token
+    = &TMH_PG_insert_spent_token;
+  plugin->insert_issued_token
+    = &TMH_PG_insert_issued_token;
+  plugin->lookup_spent_tokens_by_order
+    = &TMH_PG_lookup_spent_tokens_by_order;
+
+
 
 
   return plugin;
