@@ -35,7 +35,7 @@
 
 
 #define MERCHANT_FAIL() \
-  do {GNUNET_break (0); return NULL; } while (0)
+        do {GNUNET_break (0); return NULL; } while (0)
 
 
 /**
@@ -1260,7 +1260,7 @@ TALER_TESTING_cmd_merchant_delete_transfer (const char *label,
  *        of the bank account to check KYC for; NULL to check all accounts
  * @param exchange_url base URL of the exchange to check KYC status for
  * @param expected_http_status expected HTTP status
- * @param expected_aml_state expected AML state (only effective if @e expected_http_status is #MHD_HTTP_OK)
+ * @param expected_kyc_state expected KYC state (only effective if @e expected_http_status is #MHD_HTTP_OK/#MHD_HTTP_ACCEPTED)
  * @return the command
  */
 struct TALER_TESTING_Command
@@ -1271,7 +1271,7 @@ TALER_TESTING_cmd_merchant_kyc_get (
   const char *h_wire_ref,
   const char *exchange_url,
   unsigned int expected_http_status,
-  enum TALER_AmlDecisionState expected_aml_state);
+  bool expected_kyc_state);
 
 
 /* ****** OTP devices ******* */
@@ -1557,6 +1557,7 @@ TALER_TESTING_cmd_merchant_post_using_templates (
  * @param valid_after start of the validity time of the token family.
  * @param valid_before end of the validity time of the token family.
  * @param duration validity duration of an issued token of the token family.
+ * @param rounding to multiples of what duration should start times be rounded
  * @param kind kind of the token family. either "subscription" or "discount".
  * @return the command.
  */
@@ -1797,52 +1798,52 @@ TALER_TESTING_cmd_checkserver2 (const char *label,
  */
 // FIXME: rename: refund_entry->refund_detail
 #define TALER_MERCHANT_TESTING_SIMPLE_TRAITS(op) \
-  op (claim_nonce, const struct GNUNET_CRYPTO_EddsaPublicKey) \
-  op (pickup_id, const struct TALER_PickupIdentifierP) \
-  op (instance_name, const char) \
-  op (instance_id, const char) \
-  op (address, const json_t) \
-  op (product_description, const char) \
-  op (product_image, const char) \
-  op (product_stock, const int64_t) \
-  op (product_unit, const char) \
-  op (product_id, const char) \
-  op (reason, const char) \
-  op (lock_uuid, const char) \
-  op (auth_token, const char) \
-  op (paths_length, const uint32_t) \
-  op (payto_length, const uint32_t) \
-  op (num_planchets, const uint32_t) \
-  op (i18n_description, const json_t) \
-  op (taxes, const json_t)      \
-  op (fee, const struct TALER_Amount) \
-  op (use_stefan, const bool) \
-  op (jurisdiction, const json_t) \
-  op (wire_delay, const struct GNUNET_TIME_Relative) \
-  op (pay_delay, const struct GNUNET_TIME_Relative) \
-  op (refund_entry, const struct TALER_MERCHANT_RefundDetail) \
-  op (order_terms, const json_t) \
-  op (h_contract_terms, const struct TALER_PrivateContractHashP) \
-  op (h_wire, const struct TALER_MerchantWireHashP) \
-  op (proposal_reference, const char) \
-  op (template_description, const char) \
-  op (otp_device_description, const char) \
-  op (otp_id, const char) \
-  op (otp_key, const char) \
-  op (otp_alg, const enum TALER_MerchantConfirmationAlgorithm) \
-  op (template_id, const char) \
-  op (template_contract, const json_t) \
-  op (event_type, const char)   \
-  op (webhook_id, const char) \
-  op (merchant_base_url, const char) \
-  op (url, const char) \
-  op (http_method, const char)   \
-  op (header_template, const char)   \
-  op (body_template, const char)   \
-  op (summary, const char)   \
-  op (token_family_slug, const char)   \
-  op (token_family_duration, const struct GNUNET_TIME_Relative)   \
-  op (token_family_kind, const char)
+        op (claim_nonce, const struct GNUNET_CRYPTO_EddsaPublicKey) \
+        op (pickup_id, const struct TALER_PickupIdentifierP) \
+        op (instance_name, const char) \
+        op (instance_id, const char) \
+        op (address, const json_t) \
+        op (product_description, const char) \
+        op (product_image, const char) \
+        op (product_stock, const int64_t) \
+        op (product_unit, const char) \
+        op (product_id, const char) \
+        op (reason, const char) \
+        op (lock_uuid, const char) \
+        op (auth_token, const char) \
+        op (paths_length, const uint32_t) \
+        op (payto_length, const uint32_t) \
+        op (num_planchets, const uint32_t) \
+        op (i18n_description, const json_t) \
+        op (taxes, const json_t)      \
+        op (fee, const struct TALER_Amount) \
+        op (use_stefan, const bool) \
+        op (jurisdiction, const json_t) \
+        op (wire_delay, const struct GNUNET_TIME_Relative) \
+        op (pay_delay, const struct GNUNET_TIME_Relative) \
+        op (refund_entry, const struct TALER_MERCHANT_RefundDetail) \
+        op (order_terms, const json_t) \
+        op (h_contract_terms, const struct TALER_PrivateContractHashP) \
+        op (h_wire, const struct TALER_MerchantWireHashP) \
+        op (proposal_reference, const char) \
+        op (template_description, const char) \
+        op (otp_device_description, const char) \
+        op (otp_id, const char) \
+        op (otp_key, const char) \
+        op (otp_alg, const enum TALER_MerchantConfirmationAlgorithm) \
+        op (template_id, const char) \
+        op (template_contract, const json_t) \
+        op (event_type, const char)   \
+        op (webhook_id, const char) \
+        op (merchant_base_url, const char) \
+        op (url, const char) \
+        op (http_method, const char)   \
+        op (header_template, const char)   \
+        op (body_template, const char)   \
+        op (summary, const char)   \
+        op (token_family_slug, const char)   \
+        op (token_family_duration, const struct GNUNET_TIME_Relative)   \
+        op (token_family_kind, const char)
 
 
 /**
@@ -1851,20 +1852,20 @@ TALER_TESTING_cmd_checkserver2 (const char *label,
  * @param op macro to call
  */
 #define TALER_MERCHANT_TESTING_INDEXED_TRAITS(op) \
-  op (coin_reference, const char) \
-  op (paths, const char) \
-  op (payto_uris, const char) \
-  op (h_wires, const struct TALER_MerchantWireHashP) \
-  op (amounts, const struct TALER_Amount)         \
-  op (urls, const char) \
-  op (http_methods, const char)   \
-  op (http_header, const char)   \
-  op (http_body, const void)   \
-  op (http_body_size, const size_t)   \
-  op (planchet_secrets, const struct TALER_PlanchetMasterSecretP)   \
-  op (token_priv, const struct TALER_TokenUsePrivateKeyP)   \
-  op (token_issue_sig, const struct TALER_TokenIssueSignatureP)   \
-  op (token_issue_pub, const struct TALER_TokenIssuePublicKeyP)
+        op (coin_reference, const char) \
+        op (paths, const char) \
+        op (payto_uris, const char) \
+        op (h_wires, const struct TALER_MerchantWireHashP) \
+        op (amounts, const struct TALER_Amount)         \
+        op (urls, const char) \
+        op (http_methods, const char)   \
+        op (http_header, const char)   \
+        op (http_body, const void)   \
+        op (http_body_size, const size_t)   \
+        op (planchet_secrets, const struct TALER_PlanchetMasterSecretP)   \
+        op (token_priv, const struct TALER_TokenUsePrivateKeyP)   \
+        op (token_issue_sig, const struct TALER_TokenIssueSignatureP)   \
+        op (token_issue_pub, const struct TALER_TokenIssuePublicKeyP)
 
 
 TALER_MERCHANT_TESTING_SIMPLE_TRAITS (TALER_TESTING_MAKE_DECL_SIMPLE_TRAIT)
