@@ -86,7 +86,7 @@ TALER_MERCHANT_parse_error_details_ (const json_t *response,
   }
   else
   {
-    hr->exchange_code = (enum TALER_ErrorCode) json_integer_value (jc);
+    hr->exchange_code = (enum TALER_ErrorCode) (int) json_integer_value (jc);
   }
 
   /* handle 'exchange-hint' */
