@@ -112,16 +112,18 @@ parse_kyc (struct TALER_MERCHANT_KycGetHandle *kyc,
     for (unsigned int i = 0; i<num_pends; i++)
     {
       struct GNUNET_JSON_Specification spec[] = {
-        GNUNET_JSON_spec_mark_optional (
-          TALER_JSON_spec_web_url ("kyc_url",
-                                   &pending_kycs[i].kyc_url),
-          NULL),
-        TALER_JSON_spec_aml_decision ("aml_status",
-                                      &pending_kycs[i].aml_status),
-        TALER_JSON_spec_web_url ("exchange_url",
-                                 &pending_kycs[i].exchange_url),
-        TALER_JSON_spec_payto_uri ("payto_uri",
-                                   &pending_kycs[i].payto_uri),
+        GNUNET_JSON_spec_fixed_auto (
+          "access_token",
+          &pending_kycs[i].access_token),
+        TALER_JSON_spec_web_url (
+          "kyc_url",
+          &pending_kycs[i].kyc_url),
+        TALER_JSON_spec_web_url (
+          "exchange_url",
+          &pending_kycs[i].exchange_url),
+        TALER_JSON_spec_payto_uri (
+          "payto_uri",
+          &pending_kycs[i].payto_uri),
         GNUNET_JSON_spec_end ()
       };
 
@@ -132,6 +134,10 @@ parse_kyc (struct TALER_MERCHANT_KycGetHandle *kyc,
                              NULL, NULL))
       {
         GNUNET_break (0);
+        json_dumpf (json_array_get (pends,
+                                    i),
+                    stderr,
+                    JSON_INDENT (2));
         return GNUNET_SYSERR;
       }
     }
@@ -139,12 +145,15 @@ parse_kyc (struct TALER_MERCHANT_KycGetHandle *kyc,
     {
       uint32_t hs;
       struct GNUNET_JSON_Specification spec[] = {
-        TALER_JSON_spec_web_url ("exchange_url",
-                                 &timeout_kycs[i].exchange_url),
-        TALER_JSON_spec_ec ("exchange_code",
-                            &timeout_kycs[i].exchange_code),
-        GNUNET_JSON_spec_uint32 ("exchange_http_status",
-                                 &hs),
+        TALER_JSON_spec_web_url (
+          "exchange_url",
+          &timeout_kycs[i].exchange_url),
+        TALER_JSON_spec_ec (
+          "exchange_code",
+          &timeout_kycs[i].exchange_code),
+        GNUNET_JSON_spec_uint32 (
+          "exchange_http_status",
+          &hs),
         GNUNET_JSON_spec_end ()
       };
 
@@ -157,7 +166,8 @@ parse_kyc (struct TALER_MERCHANT_KycGetHandle *kyc,
         GNUNET_break (0);
         return GNUNET_SYSERR;
       }
-      timeout_kycs[i].exchange_http_status = (unsigned int) hs;
+      timeout_kycs[i].exchange_http_status
+        = (unsigned int) hs;
     }
     kr->details.kyc_status.pending_kycs = pending_kycs;
     kr->details.kyc_status.timeout_kycs = timeout_kycs;
