@@ -116,7 +116,7 @@ handle_transfers_get_finished (void *cls,
         size_t tds_length;
         struct TALER_MERCHANT_TransferData *tds;
         json_t *transfer;
-        unsigned int i;
+        size_t i;
         bool ok;
 
         tds_length = json_array_size (transfers);
