@@ -38,6 +38,12 @@
 #include <taler/taler_curl_lib.h>
 
 
+/**
+ * Maximum number of refunds we return.
+ */
+#define MAX_REFUNDS 1024
+
+
 /**
  * @brief An abort Handle
  */
@@ -127,7 +133,14 @@ check_abort_refund (struct TALER_MERCHANT_OrderAbortHandle *oah,
     GNUNET_break_op (0);
     return GNUNET_SYSERR;
   }
-  num_refunds = json_array_size (refunds);
+  num_refunds = (unsigned int) json_array_size (refunds);
+  if ( (json_array_size (refunds) != (size_t)  num_refunds) ||
+       (num_refunds > MAX_REFUNDS) )
+  {
+    GNUNET_break (0);
+    return GNUNET_SYSERR;
+  }
+
   {
     struct TALER_MERCHANT_AbortedCoin res[GNUNET_NZL (num_refunds)];
 
