@@ -25,6 +25,8 @@
  */
 #include "platform.h"
 #include <curl/curl.h>
+#include <gnunet/gnunet_common.h>
+#include <gnunet/gnunet_json_lib.h>
 #include <jansson.h>
 #include <microhttpd.h> /* just for HTTP status codes */
 #include <gnunet/gnunet_util_lib.h>
@@ -32,6 +34,7 @@
 #include "taler_merchant_service.h"
 #include "merchant_api_common.h"
 #include "merchant_api_curl_defaults.h"
+#include <stdio.h>
 #include <taler/taler_json_lib.h>
 #include <taler/taler_signatures.h>
 #include <taler/taler_exchange_service.h>
@@ -122,6 +125,53 @@ struct TALER_MERCHANT_OrderPayHandle
 };
 
 
+/**
+ * Parse blindly signed output tokens from response.
+ *
+ * @param token_sigs the JSON array with the token signatures. Can be NULL.
+ * @param tokens where to store the parsed tokens.
+ * @param num_tokens where to store the length of the @a tokens array.
+ */
+static enum GNUNET_GenericReturnValue
+parse_tokens (const json_t *token_sigs,
+              struct TALER_MERCHANT_OutputToken **tokens,
+              unsigned int *num_tokens)
+{
+  GNUNET_array_grow (*tokens,
+                     *num_tokens,
+                     json_array_size (token_sigs));
+
+  for (unsigned int i = 0; i<(*num_tokens); i++)
+  {
+    struct TALER_MERCHANT_OutputToken *token = &(*tokens)[i];
+    const json_t *jtoken = json_array_get (token_sigs,
+                                       i);
+
+    if (NULL == jtoken)
+    {
+      GNUNET_break (0);
+      return GNUNET_SYSERR;
+    }
+    struct GNUNET_JSON_Specification spec[] = {
+      TALER_JSON_spec_blinded_token_issue_sig ("blind_sig",
+                                               &token->blinded_sig),
+      GNUNET_JSON_spec_end ()
+    };
+
+    if (GNUNET_OK !=
+        GNUNET_JSON_parse (jtoken,
+                           spec,
+                           NULL, NULL))
+    {
+      GNUNET_break (0);
+      return GNUNET_SYSERR;
+    }
+  }
+
+  return GNUNET_YES;
+}
+
+
 /**
  * Function called when we're done processing the
  * HTTP /pay request.
@@ -142,6 +192,14 @@ handle_pay_finished (void *cls,
     .hr.reply = json
   };
 
+  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+              "Received /pay response with status code %u\n",
+              (unsigned int) response_code);
+
+  json_dumpf (json,
+              stderr,
+              JSON_INDENT (2));
+
   oph->job = NULL;
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "/pay completed with response code %u\n",
@@ -154,15 +212,17 @@ handle_pay_finished (void *cls,
   case MHD_HTTP_OK:
     if (oph->am_wallet)
     {
-      /* Here we can (and should) verify the merchant's signature */
+      const json_t *token_sigs = NULL;
       struct GNUNET_JSON_Specification spec[] = {
-        GNUNET_JSON_spec_fixed_auto (
-          "sig",
-          &pr.details.ok.merchant_sig),
+        GNUNET_JSON_spec_fixed_auto ("sig",
+                                     &pr.details.ok.merchant_sig),
         GNUNET_JSON_spec_mark_optional (
-          GNUNET_JSON_spec_string (
-            "pos_confirmation",
-            &pr.details.ok.pos_confirmation),
+          GNUNET_JSON_spec_string ("pos_confirmation",
+                                   &pr.details.ok.pos_confirmation),
+          NULL),
+        GNUNET_JSON_spec_mark_optional (
+          GNUNET_JSON_spec_array_const ("token_sigs",
+                                        &token_sigs),
           NULL),
         GNUNET_JSON_spec_end ()
       };
@@ -179,6 +239,18 @@ handle_pay_finished (void *cls,
         break;
       }
 
+      if (GNUNET_OK !=
+          parse_tokens (token_sigs,
+                        &pr.details.ok.tokens,
+                        &pr.details.ok.num_tokens))
+      {
+        GNUNET_break_op (0);
+        pr.hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
+        pr.hr.http_status = 0;
+        pr.hr.hint = "failed to parse token_sigs field in response";
+        break;
+      }
+
       if (GNUNET_OK !=
           TALER_merchant_pay_verify (&oph->h_contract_terms,
                                      &oph->merchant_pub,
@@ -308,21 +380,20 @@ TALER_MERCHANT_order_pay_frontend (
   const json_t *wallet_data,
   unsigned int num_coins,
   const struct TALER_MERCHANT_PaidCoin coins[static num_coins],
+  unsigned int num_tokens,
+  const struct TALER_MERCHANT_UsedToken tokens[static num_tokens],
+  json_t *j_output_tokens,
   TALER_MERCHANT_OrderPayCallback pay_cb,
   void *pay_cb_cls)
 {
   struct TALER_MERCHANT_OrderPayHandle *oph;
   json_t *pay_obj;
   json_t *j_coins;
+  json_t *j_tokens = NULL;
   CURL *eh;
   struct TALER_Amount total_fee;
   struct TALER_Amount total_amount;
 
-  if (0 == num_coins)
-  {
-    GNUNET_break (0);
-    return NULL;
-  }
   j_coins = json_array ();
   GNUNET_assert (NULL != j_coins);
   for (unsigned int i = 0; i<num_coins; i++)
@@ -392,9 +463,39 @@ TALER_MERCHANT_order_pay_frontend (
     }
   }
 
+  if (0 < num_tokens)
+  {
+    j_tokens = json_array ();
+    GNUNET_assert (NULL != j_tokens);
+    for (unsigned int i = 0; i<num_tokens; i++)
+    {
+      json_t *j_token;
+      const struct TALER_MERCHANT_UsedToken *ut = &tokens[i];
+
+      j_token = GNUNET_JSON_PACK (
+        GNUNET_JSON_pack_data_auto ("token_sig",
+                                    &ut->token_sig),
+        GNUNET_JSON_pack_data_auto ("token_pub",
+                                    &ut->token_pub),
+        TALER_JSON_pack_token_issue_sig ("ub_sig",
+                                        &ut->ub_sig));
+      if (0 !=
+          json_array_append_new (j_tokens,
+                                j_token))
+      {
+        GNUNET_break (0);
+        json_decref (j_tokens);
+        return NULL;
+      }
+    }
+  }
+
   pay_obj = GNUNET_JSON_PACK (
     GNUNET_JSON_pack_array_steal ("coins",
                                   j_coins),
+    GNUNET_JSON_pack_allow_null (
+      GNUNET_JSON_pack_array_steal ("tokens",
+                                    j_tokens)),
     GNUNET_JSON_pack_allow_null (
       GNUNET_JSON_pack_object_incref ("wallet_data",
                                       (json_t *) wallet_data)),
@@ -402,6 +503,10 @@ TALER_MERCHANT_order_pay_frontend (
       GNUNET_JSON_pack_string ("session_id",
                                session_id)));
 
+  json_dumpf (pay_obj,
+              stderr,
+              JSON_INDENT (2));
+
   oph = GNUNET_new (struct TALER_MERCHANT_OrderPayHandle);
   oph->ctx = ctx;
   oph->pay_cb = pay_cb;
@@ -461,7 +566,7 @@ TALER_MERCHANT_order_pay (
   const char *merchant_url,
   const char *session_id,
   const struct TALER_PrivateContractHashP *h_contract_terms,
-  const json_t *wallet_data,
+  int choice_index,
   const struct TALER_Amount *amount,
   const struct TALER_Amount *max_fee,
   const struct TALER_MerchantPublicKeyP *merchant_pub,
@@ -473,11 +578,17 @@ TALER_MERCHANT_order_pay (
   const char *order_id,
   unsigned int num_coins,
   const struct TALER_MERCHANT_PayCoin coins[static num_coins],
+  unsigned int num_tokens,
+  const struct TALER_MERCHANT_UseToken tokens[static num_tokens],
+  unsigned int num_output_tokens,
+  const struct TALER_MERCHANT_OutputToken output_tokens[static num_output_tokens],
   TALER_MERCHANT_OrderPayCallback pay_cb,
   void *pay_cb_cls)
 {
+  json_t *j_output_tokens = NULL;
+  const json_t *wallet_data = NULL;
   struct GNUNET_HashCode wallet_data_hash;
-  
+
   if (GNUNET_YES !=
       TALER_amount_cmp_currency (amount,
                                  max_fee))
@@ -485,11 +596,51 @@ TALER_MERCHANT_order_pay (
     GNUNET_break (0);
     return NULL;
   }
-  if (NULL != wallet_data)
+  if ((0 < num_tokens || 0 < num_output_tokens) && 0 > choice_index)
+  {
+    /* Tokens (input or output) require a valid choice_index to be set.
+       Only contracts with coices can use or issue tokens. */
+    GNUNET_break (0);
+    return NULL;
+  }
+  if (0 < num_output_tokens)
+  {
+    /* Build token envelopes json array. */
+    j_output_tokens = json_array ();
+    GNUNET_assert (NULL != j_output_tokens);
+    for (unsigned int i = 0; i<num_output_tokens; i++)
+    {
+      json_t *j_token_ev;
+      const struct TALER_MERCHANT_OutputToken *ev = &output_tokens[i];
+
+      j_token_ev = GNUNET_JSON_PACK (
+        TALER_JSON_pack_token_envelope ("token_ev",
+                                        &ev->envelope));
+
+      if (0 !=
+          json_array_append_new (j_output_tokens,
+                                j_token_ev))
+      {
+        GNUNET_break (0);
+        json_decref (j_output_tokens);
+        return NULL;
+      }
+    }
+  }
+  if (0 <= choice_index)
+  {
+    wallet_data = GNUNET_JSON_PACK (
+      GNUNET_JSON_pack_int64 ("choice_index",
+                              choice_index),
+      GNUNET_JSON_pack_allow_null (
+        GNUNET_JSON_pack_array_incref ("tokens_evs",
+                                      j_output_tokens)));
     TALER_json_hash (wallet_data,
-                     &wallet_data_hash);
+                    &wallet_data_hash);
+  }
   {
     struct TALER_MERCHANT_PaidCoin pc[num_coins];
+    struct TALER_MERCHANT_UsedToken ut[num_tokens];
 
     for (unsigned int i = 0; i<num_coins; i++)
     {
@@ -534,6 +685,20 @@ TALER_MERCHANT_order_pay (
       p->amount_without_fee = coin->amount_without_fee;
       p->exchange_url = coin->exchange_url;
     }
+    for (unsigned int i = 0; i<num_tokens; i++)
+    {
+      const struct TALER_MERCHANT_UseToken *token = &tokens[i];
+      struct TALER_MERCHANT_UsedToken *t = &ut[i];
+
+      TALER_wallet_token_use_sign (h_contract_terms,
+                                   &wallet_data_hash, // checked for != NULL above
+                                   &token->token_priv,
+                                   &t->token_sig);
+      t->ub_sig = token->ub_sig;
+      t->issue_pub = token->issue_pub;
+      GNUNET_CRYPTO_eddsa_key_get_public (&token->token_priv.private_key,
+                                          &t->token_pub.public_key);
+    }
     {
       struct TALER_MERCHANT_OrderPayHandle *oph;
 
@@ -544,6 +709,9 @@ TALER_MERCHANT_order_pay (
                                                wallet_data,
                                                num_coins,
                                                pc,
+                                               num_tokens,
+                                               ut,
+                                               j_output_tokens,
                                                pay_cb,
                                                pay_cb_cls);
       if (NULL == oph)
