@@ -138,6 +138,39 @@ TALER_MERCHANT_orders_post2 (
   bool create_token,
   TALER_MERCHANT_PostOrdersCallback cb,
   void *cb_cls)
+{
+  return TALER_MERCHANT_orders_post3 (
+    ctx,
+    backend_url,
+    order,
+    NULL, /* session ID */
+    refund_delay,
+    payment_target,
+    inventory_products_length,
+    inventory_products,
+    uuids_length,
+    uuids,
+    create_token,
+    cb,
+    cb_cls);
+}
+
+
+struct TALER_MERCHANT_PostOrdersHandle *
+TALER_MERCHANT_orders_post3 (
+  struct GNUNET_CURL_Context *ctx,
+  const char *backend_url,
+  const json_t *order,
+  const char *session_id,
+  struct GNUNET_TIME_Relative refund_delay,
+  const char *payment_target,
+  unsigned int inventory_products_length,
+  const struct TALER_MERCHANT_InventoryProduct inventory_products[],
+  unsigned int uuids_length,
+  const char *uuids[static uuids_length],
+  bool create_token,
+  TALER_MERCHANT_PostOrdersCallback cb,
+  void *cb_cls)
 {
   struct TALER_MERCHANT_PostOrdersHandle *po;
   json_t *req;
@@ -153,6 +186,9 @@ TALER_MERCHANT_orders_post2 (
   req = GNUNET_JSON_PACK (
     GNUNET_JSON_pack_object_incref ("order",
                                     (json_t *) order),
+    GNUNET_JSON_pack_allow_null (
+      GNUNET_JSON_pack_string ("session_id",
+                               session_id)),
     GNUNET_JSON_pack_allow_null (
       GNUNET_JSON_pack_string ("payment_target",
                                payment_target)));
