@@ -25,21 +25,17 @@ set -eu
 unset XDG_DATA_HOME
 unset XDG_CONFIG_HOME
 
-# Exit, with status code "skip" (no 'real' failure)
-function exit_skip() {
-    echo $1
-    exit 77
-}
+. setup.sh
 
-# If CLI is installed, assume all the suite is.
-echo -n "Testing for libeufin(-cli)"
-libeufin-cli --help >/dev/null </dev/null || exit_skip " MISSING"
+echo -n "Testing for libeufin-bank"
+libeufin-bank --help >/dev/null </dev/null || exit_skip " MISSING"
 echo " FOUND"
 
 echo -n "Testing for taler-harness"
 taler-harness --help >/dev/null </dev/null || exit_skip " MISSING"
 echo " FOUND"
 
+
 export WALLET_HARNESS_WITH_EUFIN=1
 res=0
 taler-harness run-integrationtests --dry --suites merchant 2&>/dev/null || res=$?
