@@ -52,7 +52,7 @@ fi
 STATUS=$(curl -H "Content-Type: application/json" -X POST \
     -H 'Authorization: Bearer secret-token:new_value' \
     http://localhost:9966/private/accounts \
-    -d '{"payto_uri":"payto://x-taler-bank/localhost:8082/43"}' \
+    -d '{"payto_uri":"payto://x-taler-bank/localhost:8082/43?receiver-name=user43"}' \
     -w "%{http_code}" -s -o /dev/null)
 
 
