@@ -109,7 +109,7 @@ get_transfers_cb (
     if (gtr->details.ok.transfers_length != gts->transfers_length)
     {
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                  "Transfers length does not match (%u/%u)\n",
+                  "Transfers length does not match (got %u/want %u)\n",
                   gtr->details.ok.transfers_length,
                   gts->transfers_length);
       TALER_TESTING_interpreter_fail (gts->is);
