@@ -67,15 +67,20 @@ struct KycGetState
    */
   struct TALER_PaytoHashP h_payto;
 
+  /**
+   * Access token the user needs to start a KYC process.
+   */
+  struct TALER_AccountAccessTokenP access_token;
+
   /**
    * Expected HTTP response code.
    */
   unsigned int expected_http_status;
 
   /**
-   * Expected AML state.
+   * Expected KYC state.
    */
-  enum TALER_AmlDecisionState expected_aml_state;
+  bool expected_kyc_state;
 
   /**
    * Interpreter state.
@@ -131,94 +136,28 @@ kyc_get_cb (void *cls,
   switch (kr->hr.http_status)
   {
   case MHD_HTTP_ACCEPTED:
-
-    if ( ( (TALER_AML_NORMAL != cs->expected_aml_state) &&
-           (0 == kr->details.kyc_status.pending_kycs_length) ) ||
-         ( (0 < kr->details.kyc_status.pending_kycs_length) &&
-           (cs->expected_aml_state !=
-            kr->details.kyc_status.pending_kycs[0].aml_status) ) )
+    if (! cs->expected_kyc_state)
     {
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                  "Expected AML state %u, got %u/%u\n",
-                  cs->expected_aml_state,
-                  kr->details.kyc_status.pending_kycs[0].aml_status,
+                  "Expected KYC state %u, got %u\n",
+                  cs->expected_kyc_state,
                   kr->details.kyc_status.pending_kycs_length);
       TALER_TESTING_FAIL (cs->is);
     }
     for (unsigned int i = 0; i<kr->details.kyc_status.pending_kycs_length; i++)
     {
-      const char *url;
-      const char *tok;
-      const char *end;
-      char *dec;
-      const char *eq;
-      const char *nq;
-      size_t toklen;
+      const char *payto_uri;
 
-      url = kr->details.kyc_status.pending_kycs[i].kyc_url;
-      if (NULL == url)
+      payto_uri = kr->details.kyc_status.pending_kycs[i].payto_uri;
+      if (NULL == payto_uri)
       {
-        /* AML status here must be either pending or frozne */
-        switch (kr->details.kyc_status.pending_kycs[i].aml_status)
-        {
-        case TALER_AML_NORMAL:
-          TALER_TESTING_FAIL (cs->is);
-        case TALER_AML_PENDING:
-          continue;
-        case TALER_AML_FROZEN:
-          continue;
-        }
-        TALER_TESTING_FAIL (cs->is);
-      }
-      tok = strstr (url, "&redirect_uri=");
-      if (NULL == tok)
-        TALER_TESTING_FAIL (cs->is);
-      tok += strlen ("&redirect_uri=");
-      end = strchr (tok, '&');
-      if (NULL == end)
-        toklen = strlen (tok);
-      else
-        toklen = end - tok;
-      (void) GNUNET_STRINGS_urldecode (tok,
-                                       toklen,
-                                       &dec);
-      eq = strstr (dec, "/kyc-proof/");
-      if (NULL == eq)
-      {
-        GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                    "Received unexpected KYC URL `%s' (%s)\n",
-                    url,
-                    dec);
-        GNUNET_free (dec);
-        TALER_TESTING_FAIL (cs->is);
-      }
-      GNUNET_free (dec);
-
-      eq = strstr (url, "&state=");
-      if (NULL == eq)
-      {
-        GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                    "Received unexpected 'state'-less KYC URL `%s' (%s)\n",
-                    url,
-                    dec);
-        TALER_TESTING_FAIL (cs->is);
-      }
-      eq += strlen ("&state=");
-      nq = strchr (eq, '&');
-      if (NULL == nq)
-        nq = eq + strlen (eq);
-      if (GNUNET_OK !=
-          GNUNET_STRINGS_string_to_data (eq,
-                                         nq - eq,
-                                         &cs->h_payto,
-                                         sizeof (cs->h_payto)))
-      {
-        GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                    "Received unexpected KYC URL `%s' (%s) - no h_payto in state\n",
-                    url,
-                    eq);
-        TALER_TESTING_FAIL (cs->is);
+        continue;
       }
+      TALER_payto_hash (payto_uri,
+                        &cs->h_payto);
+      cs->access_token
+        = kr->details.kyc_status.pending_kycs[i].access_token;
+      break;
     }
     break;
   }
@@ -265,14 +204,14 @@ kyc_get_run (void *cls,
     }
   }
   if (NULL == cs->instance_id)
-    cs->kgh = TALER_MERCHANT_kyc_get (TALER_TESTING_interpreter_get_context (
-                                        is),
-                                      cs->merchant_url,
-                                      h_wire,
-                                      cs->exchange_url,
-                                      GNUNET_TIME_UNIT_ZERO,
-                                      &kyc_get_cb,
-                                      cs);
+    cs->kgh = TALER_MERCHANT_kyc_get (
+      TALER_TESTING_interpreter_get_context (is),
+      cs->merchant_url,
+      h_wire,
+      cs->exchange_url,
+      GNUNET_TIME_UNIT_ZERO,
+      &kyc_get_cb,
+      cs);
   else
     cs->kgh = TALER_MERCHANT_management_kyc_get (
       TALER_TESTING_interpreter_get_context (is),
@@ -307,6 +246,8 @@ kyc_get_traits (void *cls,
   struct TALER_TESTING_Trait traits[] = {
     TALER_TESTING_make_trait_h_payto (
       &cs->h_payto),
+    TALER_TESTING_make_trait_account_access_token (
+      &cs->access_token),
     TALER_TESTING_trait_end ()
   };
 
@@ -325,7 +266,7 @@ TALER_TESTING_cmd_merchant_kyc_get (
   const char *h_wire_ref,
   const char *exchange_url,
   unsigned int expected_http_status,
-  enum TALER_AmlDecisionState expected_aml_state)
+  bool expected_kyc_state)
 {
   struct KycGetState *cs;
 
@@ -335,7 +276,7 @@ TALER_TESTING_cmd_merchant_kyc_get (
   cs->h_wire_ref = h_wire_ref;
   cs->exchange_url = exchange_url;
   cs->expected_http_status = expected_http_status;
-  cs->expected_aml_state = expected_aml_state;
+  cs->expected_kyc_state = expected_kyc_state;
   {
     struct TALER_TESTING_Command cmd = {
       .cls = cs,
